@@ -5,18 +5,9 @@ Currently only includes to_coo helpers.
 """
 from __future__ import annotations
 
-from typing import (
-    TYPE_CHECKING,
-    Iterable,
-)
-
-import numpy as np
+from typing import TYPE_CHECKING
 
 from pandas._libs import lib
-from pandas._typing import (
-    IndexLabel,
-    npt,
-)
 
 from pandas.core.dtypes.missing import notna
 
@@ -25,8 +16,16 @@ from pandas.core.indexes.api import MultiIndex
 from pandas.core.series import Series
 
 if TYPE_CHECKING:
+    from collections.abc import Iterable
+
+    import numpy as np
     import scipy.sparse
 
+    from pandas._typing import (
+        IndexLabel,
+        npt,
+    )
+
 
 def _check_is_partition(parts: Iterable, whole: Iterable):
     whole = set(whole)
@@ -73,7 +72,7 @@ def _levels_to_axis(
 
     else:
         levels_values = lib.fast_zip(
-            [ss.index.get_level_values(lvl).values for lvl in levels]
+            [ss.index.get_level_values(lvl).to_numpy() for lvl in levels]
         )
         codes, ax_labels = factorize(levels_values, sort=sort_labels)
         ax_coords = codes[valid_ilocs]
@@ -177,7 +176,7 @@ def coo_to_sparse_series(
     A: scipy.sparse.coo_matrix, dense_index: bool = False
 ) -> Series:
     """
-    Convert a scipy.sparse.coo_matrix to a SparseSeries.
+    Convert a scipy.sparse.coo_matrix to a Series with type sparse.
 
     Parameters
     ----------
@@ -195,7 +194,7 @@ def coo_to_sparse_series(
     from pandas import SparseDtype
 
     try:
-        ser = Series(A.data, MultiIndex.from_arrays((A.row, A.col)))
+        ser = Series(A.data, MultiIndex.from_arrays((A.row, A.col)), copy=False)
     except AttributeError as err:
         raise TypeError(
             f"Expected coo_matrix. Got {type(A).__name__} instead."
@@ -203,9 +202,6 @@ def coo_to_sparse_series(
     ser = ser.sort_index()
     ser = ser.astype(SparseDtype(ser.dtype))
     if dense_index:
-        # is there a better constructor method to use here?
-        i = range(A.shape[0])
-        j = range(A.shape[1])
-        ind = MultiIndex.from_product([i, j])
+        ind = MultiIndex.from_product([A.row, A.col])
         ser = ser.reindex(ind)
     return ser
