@@ -1,6 +1,7 @@
 import pytest
 
 import pandas as pd
+import pandas._testing as tm
 from pandas.tests.arrays.masked_shared import (
     ComparisonOps,
     NumericOps,
@@ -25,7 +26,7 @@ class TestComparisonOps(NumericOps, ComparisonOps):
         expected = method(2).astype("boolean")
         expected[s2.isna()] = pd.NA
 
-        self.assert_series_equal(result, expected)
+        tm.assert_series_equal(result, expected)
 
 
 def test_equals():
