@@ -4,126 +4,54 @@ import pytest
 from pandas.errors import InvalidIndexError
 
 from pandas import (
+    NA,
     Index,
     RangeIndex,
     Series,
     Timestamp,
 )
 import pandas._testing as tm
-from pandas.core.indexes.api import (
-    Float64Index,
-    Int64Index,
-    UInt64Index,
+from pandas.core.arrays import (
+    ArrowExtensionArray,
+    FloatingArray,
 )
 
 
 @pytest.fixture
 def index_large():
-    # large values used in UInt64Index tests where no compat needed with Int64/Float64
+    # large values used in Index[uint64] tests where no compat needed with Int64/Float64
     large = [2**63, 2**63 + 10, 2**63 + 15, 2**63 + 20, 2**63 + 25]
-    return UInt64Index(large)
+    return Index(large, dtype=np.uint64)
 
 
 class TestGetLoc:
-    @pytest.mark.parametrize("method", [None, "pad", "backfill", "nearest"])
-    def test_get_loc(self, method):
+    def test_get_loc(self):
         index = Index([0, 1, 2])
-        warn = None if method is None else FutureWarning
+        assert index.get_loc(1) == 1
 
-        with tm.assert_produces_warning(warn, match="deprecated"):
-            assert index.get_loc(1, method=method) == 1
-
-        if method:
-            with tm.assert_produces_warning(warn, match="deprecated"):
-                assert index.get_loc(1, method=method, tolerance=0) == 1
-
-    @pytest.mark.parametrize("method", [None, "pad", "backfill", "nearest"])
-    @pytest.mark.filterwarnings("ignore:Passing method:FutureWarning")
-    def test_get_loc_raises_bad_label(self, method):
+    def test_get_loc_raises_bad_label(self):
         index = Index([0, 1, 2])
-        if method:
-            msg = "not supported between"
-            err = TypeError
-        else:
-            msg = r"\[1, 2\]"
-            err = InvalidIndexError
+        with pytest.raises(InvalidIndexError, match=r"\[1, 2\]"):
+            index.get_loc([1, 2])
 
-        with pytest.raises(err, match=msg):
-            index.get_loc([1, 2], method=method)
-
-    @pytest.mark.parametrize(
-        "method,loc", [("pad", 1), ("backfill", 2), ("nearest", 1)]
-    )
-    @pytest.mark.filterwarnings("ignore:Passing method:FutureWarning")
-    def test_get_loc_tolerance(self, method, loc):
-        index = Index([0, 1, 2])
-        assert index.get_loc(1.1, method) == loc
-        assert index.get_loc(1.1, method, tolerance=1) == loc
-
-    @pytest.mark.parametrize("method", ["pad", "backfill", "nearest"])
-    def test_get_loc_outside_tolerance_raises(self, method):
-        index = Index([0, 1, 2])
-        with pytest.raises(KeyError, match="1.1"):
-            with tm.assert_produces_warning(FutureWarning, match="deprecated"):
-                index.get_loc(1.1, method, tolerance=0.05)
-
-    def test_get_loc_bad_tolerance_raises(self):
-        index = Index([0, 1, 2])
-        with pytest.raises(ValueError, match="must be numeric"):
-            with tm.assert_produces_warning(FutureWarning, match="deprecated"):
-                index.get_loc(1.1, "nearest", tolerance="invalid")
-
-    def test_get_loc_tolerance_no_method_raises(self):
-        index = Index([0, 1, 2])
-        with pytest.raises(ValueError, match="tolerance .* valid if"):
-            index.get_loc(1.1, tolerance=1)
-
-    def test_get_loc_raises_missized_tolerance(self):
-        index = Index([0, 1, 2])
-        with pytest.raises(ValueError, match="tolerance size must match"):
-            with tm.assert_produces_warning(FutureWarning, match="deprecated"):
-                index.get_loc(1.1, "nearest", tolerance=[1, 1])
-
-    @pytest.mark.filterwarnings("ignore:Passing method:FutureWarning")
     def test_get_loc_float64(self):
-        idx = Float64Index([0.0, 1.0, 2.0])
-        for method in [None, "pad", "backfill", "nearest"]:
-            assert idx.get_loc(1, method) == 1
-            if method is not None:
-                assert idx.get_loc(1, method, tolerance=0) == 1
-
-        for method, loc in [("pad", 1), ("backfill", 2), ("nearest", 1)]:
-            assert idx.get_loc(1.1, method) == loc
-            assert idx.get_loc(1.1, method, tolerance=0.9) == loc
+        idx = Index([0.0, 1.0, 2.0], dtype=np.float64)
 
         with pytest.raises(KeyError, match="^'foo'$"):
             idx.get_loc("foo")
         with pytest.raises(KeyError, match=r"^1\.5$"):
             idx.get_loc(1.5)
-        with pytest.raises(KeyError, match=r"^1\.5$"):
-            idx.get_loc(1.5, method="pad", tolerance=0.1)
         with pytest.raises(KeyError, match="^True$"):
             idx.get_loc(True)
         with pytest.raises(KeyError, match="^False$"):
             idx.get_loc(False)
 
-        with pytest.raises(ValueError, match="must be numeric"):
-            idx.get_loc(1.4, method="nearest", tolerance="foo")
-
-        with pytest.raises(ValueError, match="must contain numeric elements"):
-            idx.get_loc(1.4, method="nearest", tolerance=np.array(["foo"]))
-
-        with pytest.raises(
-            ValueError, match="tolerance size must match target index size"
-        ):
-            idx.get_loc(1.4, method="nearest", tolerance=np.array([1, 2]))
-
     def test_get_loc_na(self):
-        idx = Float64Index([np.nan, 1, 2])
+        idx = Index([np.nan, 1, 2], dtype=np.float64)
         assert idx.get_loc(1) == 1
         assert idx.get_loc(np.nan) == 0
 
-        idx = Float64Index([np.nan, 1, np.nan])
+        idx = Index([np.nan, 1, np.nan], dtype=np.float64)
         assert idx.get_loc(1) == 1
 
         # representable by slice [0:2:2]
@@ -131,7 +59,7 @@ class TestGetLoc:
         with pytest.raises(KeyError, match=msg):
             idx.slice_locs(np.nan)
         # not representable by slice
-        idx = Float64Index([np.nan, 1, np.nan, np.nan])
+        idx = Index([np.nan, 1, np.nan, np.nan], dtype=np.float64)
         assert idx.get_loc(1) == 1
         msg = "'Cannot get left slice bound for non-unique label: nan"
         with pytest.raises(KeyError, match=msg):
@@ -139,7 +67,7 @@ class TestGetLoc:
 
     def test_get_loc_missing_nan(self):
         # GH#8569
-        idx = Float64Index([1, 2])
+        idx = Index([1, 2], dtype=np.float64)
         assert idx.get_loc(1) == 0
         with pytest.raises(KeyError, match=r"^3$"):
             idx.get_loc(3)
@@ -150,13 +78,11 @@ class TestGetLoc:
             idx.get_loc([np.nan])
 
     @pytest.mark.parametrize("vals", [[1], [1.0], [Timestamp("2019-12-31")], ["test"]])
-    @pytest.mark.parametrize("method", ["nearest", "pad", "backfill"])
-    def test_get_loc_float_index_nan_with_method(self, vals, method):
+    def test_get_loc_float_index_nan_with_method(self, vals):
         # GH#39382
         idx = Index(vals)
         with pytest.raises(KeyError, match="nan"):
-            with tm.assert_produces_warning(FutureWarning, match="deprecated"):
-                idx.get_loc(np.nan, method=method)
+            idx.get_loc(np.nan)
 
     @pytest.mark.parametrize("dtype", ["f8", "i8", "u8"])
     def test_get_loc_numericindex_none_raises(self, dtype):
@@ -285,14 +211,16 @@ class TestGetIndexer:
         actual = index.get_indexer([0.2, 1.8, 8.5], method=method)
         tm.assert_numpy_array_equal(actual, np.array(expected, dtype=np.intp))
 
-    @pytest.mark.parametrize(
-        "idx_class", [Int64Index, RangeIndex, Float64Index, UInt64Index]
-    )
+    @pytest.mark.parametrize("idx_dtype", ["int64", "float64", "uint64", "range"])
     @pytest.mark.parametrize("method", ["get_indexer", "get_indexer_non_unique"])
-    def test_get_indexer_numeric_index_boolean_target(self, method, idx_class):
+    def test_get_indexer_numeric_index_boolean_target(self, method, idx_dtype):
         # GH 16877
 
-        numeric_index = idx_class(RangeIndex(4))
+        if idx_dtype == "range":
+            numeric_index = RangeIndex(4)
+        else:
+            numeric_index = Index(np.arange(4, dtype=idx_dtype))
+
         other = Index([True, False, True])
 
         result = getattr(numeric_index, method)(other)
@@ -336,7 +264,7 @@ class TestGetIndexer:
         tm.assert_numpy_array_equal(res, expected)
 
     def test_get_indexer_float64(self):
-        idx = Float64Index([0.0, 1.0, 2.0])
+        idx = Index([0.0, 1.0, 2.0], dtype=np.float64)
         tm.assert_numpy_array_equal(
             idx.get_indexer(idx), np.array([0, 1, 2], dtype=np.intp)
         )
@@ -354,51 +282,144 @@ class TestGetIndexer:
 
     def test_get_indexer_nan(self):
         # GH#7820
-        result = Float64Index([1, 2, np.nan]).get_indexer([np.nan])
+        result = Index([1, 2, np.nan], dtype=np.float64).get_indexer([np.nan])
         expected = np.array([2], dtype=np.intp)
         tm.assert_numpy_array_equal(result, expected)
 
     def test_get_indexer_int64(self):
-        index = Int64Index(range(0, 20, 2))
-        target = Int64Index(np.arange(10))
+        index = Index(range(0, 20, 2), dtype=np.int64)
+        target = Index(np.arange(10), dtype=np.int64)
         indexer = index.get_indexer(target)
         expected = np.array([0, -1, 1, -1, 2, -1, 3, -1, 4, -1], dtype=np.intp)
         tm.assert_numpy_array_equal(indexer, expected)
 
-        target = Int64Index(np.arange(10))
+        target = Index(np.arange(10), dtype=np.int64)
         indexer = index.get_indexer(target, method="pad")
         expected = np.array([0, 0, 1, 1, 2, 2, 3, 3, 4, 4], dtype=np.intp)
         tm.assert_numpy_array_equal(indexer, expected)
 
-        target = Int64Index(np.arange(10))
+        target = Index(np.arange(10), dtype=np.int64)
         indexer = index.get_indexer(target, method="backfill")
         expected = np.array([0, 1, 1, 2, 2, 3, 3, 4, 4, 5], dtype=np.intp)
         tm.assert_numpy_array_equal(indexer, expected)
 
     def test_get_indexer_uint64(self, index_large):
-        target = UInt64Index(np.arange(10).astype("uint64") * 5 + 2**63)
+        target = Index(np.arange(10).astype("uint64") * 5 + 2**63)
         indexer = index_large.get_indexer(target)
         expected = np.array([0, -1, 1, 2, 3, 4, -1, -1, -1, -1], dtype=np.intp)
         tm.assert_numpy_array_equal(indexer, expected)
 
-        target = UInt64Index(np.arange(10).astype("uint64") * 5 + 2**63)
+        target = Index(np.arange(10).astype("uint64") * 5 + 2**63)
         indexer = index_large.get_indexer(target, method="pad")
         expected = np.array([0, 0, 1, 2, 3, 4, 4, 4, 4, 4], dtype=np.intp)
         tm.assert_numpy_array_equal(indexer, expected)
 
-        target = UInt64Index(np.arange(10).astype("uint64") * 5 + 2**63)
+        target = Index(np.arange(10).astype("uint64") * 5 + 2**63)
         indexer = index_large.get_indexer(target, method="backfill")
         expected = np.array([0, 1, 1, 2, 3, 4, -1, -1, -1, -1], dtype=np.intp)
         tm.assert_numpy_array_equal(indexer, expected)
 
+    @pytest.mark.parametrize("val, val2", [(4, 5), (4, 4), (4, NA), (NA, NA)])
+    def test_get_loc_masked(self, val, val2, any_numeric_ea_and_arrow_dtype):
+        # GH#39133
+        idx = Index([1, 2, 3, val, val2], dtype=any_numeric_ea_and_arrow_dtype)
+        result = idx.get_loc(2)
+        assert result == 1
+
+        with pytest.raises(KeyError, match="9"):
+            idx.get_loc(9)
+
+    def test_get_loc_masked_na(self, any_numeric_ea_and_arrow_dtype):
+        # GH#39133
+        idx = Index([1, 2, NA], dtype=any_numeric_ea_and_arrow_dtype)
+        result = idx.get_loc(NA)
+        assert result == 2
+
+        idx = Index([1, 2, NA, NA], dtype=any_numeric_ea_and_arrow_dtype)
+        result = idx.get_loc(NA)
+        tm.assert_numpy_array_equal(result, np.array([False, False, True, True]))
+
+        idx = Index([1, 2, 3], dtype=any_numeric_ea_and_arrow_dtype)
+        with pytest.raises(KeyError, match="NA"):
+            idx.get_loc(NA)
+
+    def test_get_loc_masked_na_and_nan(self):
+        # GH#39133
+        idx = Index(
+            FloatingArray(
+                np.array([1, 2, 1, np.nan]), mask=np.array([False, False, True, False])
+            )
+        )
+        result = idx.get_loc(NA)
+        assert result == 2
+        result = idx.get_loc(np.nan)
+        assert result == 3
+
+        idx = Index(
+            FloatingArray(np.array([1, 2, 1.0]), mask=np.array([False, False, True]))
+        )
+        result = idx.get_loc(NA)
+        assert result == 2
+        with pytest.raises(KeyError, match="nan"):
+            idx.get_loc(np.nan)
+
+        idx = Index(
+            FloatingArray(
+                np.array([1, 2, np.nan]), mask=np.array([False, False, False])
+            )
+        )
+        result = idx.get_loc(np.nan)
+        assert result == 2
+        with pytest.raises(KeyError, match="NA"):
+            idx.get_loc(NA)
+
+    @pytest.mark.parametrize("val", [4, 2])
+    def test_get_indexer_masked_na(self, any_numeric_ea_and_arrow_dtype, val):
+        # GH#39133
+        idx = Index([1, 2, NA, 3, val], dtype=any_numeric_ea_and_arrow_dtype)
+        result = idx.get_indexer_for([1, NA, 5])
+        expected = np.array([0, 2, -1])
+        tm.assert_numpy_array_equal(result, expected, check_dtype=False)
+
+    @pytest.mark.parametrize("dtype", ["boolean", "bool[pyarrow]"])
+    def test_get_indexer_masked_na_boolean(self, dtype):
+        # GH#39133
+        if dtype == "bool[pyarrow]":
+            pytest.importorskip("pyarrow")
+        idx = Index([True, False, NA], dtype=dtype)
+        result = idx.get_loc(False)
+        assert result == 1
+        result = idx.get_loc(NA)
+        assert result == 2
+
+    def test_get_indexer_arrow_dictionary_target(self):
+        pa = pytest.importorskip("pyarrow")
+        target = Index(
+            ArrowExtensionArray(
+                pa.array([1, 2], type=pa.dictionary(pa.int8(), pa.int8()))
+            )
+        )
+        idx = Index([1])
+
+        result = idx.get_indexer(target)
+        expected = np.array([0, -1], dtype=np.int64)
+        tm.assert_numpy_array_equal(result, expected)
+
+        result_1, result_2 = idx.get_indexer_non_unique(target)
+        expected_1, expected_2 = np.array([0, -1], dtype=np.int64), np.array(
+            [1], dtype=np.int64
+        )
+        tm.assert_numpy_array_equal(result_1, expected_1)
+        tm.assert_numpy_array_equal(result_2, expected_2)
+
 
 class TestWhere:
     @pytest.mark.parametrize(
         "index",
         [
-            Float64Index(np.arange(5, dtype="float64")),
-            Int64Index(range(0, 20, 2)),
-            UInt64Index(np.arange(5, dtype="uint64")),
+            Index(np.arange(5, dtype="float64")),
+            Index(range(0, 20, 2), dtype=np.int64),
+            Index(np.arange(5, dtype="uint64")),
         ],
     )
     def test_where(self, listlike_box, index):
@@ -407,16 +428,16 @@ class TestWhere:
         result = index.where(listlike_box(cond))
 
         cond = [False] + [True] * (len(index) - 1)
-        expected = Float64Index([index._na_value] + index[1:].tolist())
+        expected = Index([index._na_value] + index[1:].tolist(), dtype=np.float64)
         result = index.where(listlike_box(cond))
         tm.assert_index_equal(result, expected)
 
     def test_where_uint64(self):
-        idx = UInt64Index([0, 6, 2])
+        idx = Index([0, 6, 2], dtype=np.uint64)
         mask = np.array([False, True, False])
         other = np.array([1], dtype=np.int64)
 
-        expected = UInt64Index([1, 6, 1])
+        expected = Index([1, 6, 1], dtype=np.uint64)
 
         result = idx.where(mask, other)
         tm.assert_index_equal(result, expected)
@@ -424,29 +445,40 @@ class TestWhere:
         result = idx.putmask(~mask, other)
         tm.assert_index_equal(result, expected)
 
+    def test_where_infers_type_instead_of_trying_to_convert_string_to_float(self):
+        # GH 32413
+        index = Index([1, np.nan])
+        cond = index.notna()
+        other = Index(["a", "b"], dtype="string")
+
+        expected = Index([1.0, "b"])
+        result = index.where(cond, other)
+
+        tm.assert_index_equal(result, expected)
+
 
 class TestTake:
-    @pytest.mark.parametrize("klass", [Float64Index, Int64Index, UInt64Index])
-    def test_take_preserve_name(self, klass):
-        index = klass([1, 2, 3, 4], name="foo")
+    @pytest.mark.parametrize("idx_dtype", [np.float64, np.int64, np.uint64])
+    def test_take_preserve_name(self, idx_dtype):
+        index = Index([1, 2, 3, 4], dtype=idx_dtype, name="foo")
         taken = index.take([3, 0, 1])
         assert index.name == taken.name
 
     def test_take_fill_value_float64(self):
         # GH 12631
-        idx = Float64Index([1.0, 2.0, 3.0], name="xxx")
+        idx = Index([1.0, 2.0, 3.0], name="xxx", dtype=np.float64)
         result = idx.take(np.array([1, 0, -1]))
-        expected = Float64Index([2.0, 1.0, 3.0], name="xxx")
+        expected = Index([2.0, 1.0, 3.0], dtype=np.float64, name="xxx")
         tm.assert_index_equal(result, expected)
 
         # fill_value
         result = idx.take(np.array([1, 0, -1]), fill_value=True)
-        expected = Float64Index([2.0, 1.0, np.nan], name="xxx")
+        expected = Index([2.0, 1.0, np.nan], dtype=np.float64, name="xxx")
         tm.assert_index_equal(result, expected)
 
         # allow_fill=False
         result = idx.take(np.array([1, 0, -1]), allow_fill=False, fill_value=True)
-        expected = Float64Index([2.0, 1.0, 3.0], name="xxx")
+        expected = Index([2.0, 1.0, 3.0], dtype=np.float64, name="xxx")
         tm.assert_index_equal(result, expected)
 
         msg = (
@@ -462,15 +494,15 @@ class TestTake:
         with pytest.raises(IndexError, match=msg):
             idx.take(np.array([1, -5]))
 
-    @pytest.mark.parametrize("klass", [Int64Index, UInt64Index])
-    def test_take_fill_value_ints(self, klass):
+    @pytest.mark.parametrize("dtype", [np.int64, np.uint64])
+    def test_take_fill_value_ints(self, dtype):
         # see gh-12631
-        idx = klass([1, 2, 3], name="xxx")
+        idx = Index([1, 2, 3], dtype=dtype, name="xxx")
         result = idx.take(np.array([1, 0, -1]))
-        expected = klass([2, 1, 3], name="xxx")
+        expected = Index([2, 1, 3], dtype=dtype, name="xxx")
         tm.assert_index_equal(result, expected)
 
-        name = klass.__name__
+        name = type(idx).__name__
         msg = f"Unable to fill values because {name} cannot contain NA"
 
         # fill_value=True
@@ -479,7 +511,7 @@ class TestTake:
 
         # allow_fill=False
         result = idx.take(np.array([1, 0, -1]), allow_fill=False, fill_value=True)
-        expected = klass([2, 1, 3], name="xxx")
+        expected = Index([2, 1, 3], dtype=dtype, name="xxx")
         tm.assert_index_equal(result, expected)
 
         with pytest.raises(ValueError, match=msg):
@@ -493,18 +525,18 @@ class TestTake:
 
 
 class TestContains:
-    @pytest.mark.parametrize("klass", [Float64Index, Int64Index, UInt64Index])
-    def test_contains_none(self, klass):
+    @pytest.mark.parametrize("dtype", [np.float64, np.int64, np.uint64])
+    def test_contains_none(self, dtype):
         # GH#35788 should return False, not raise TypeError
-        index = klass([0, 1, 2, 3, 4])
+        index = Index([0, 1, 2, 3, 4], dtype=dtype)
         assert None not in index
 
     def test_contains_float64_nans(self):
-        index = Float64Index([1.0, 2.0, np.nan])
+        index = Index([1.0, 2.0, np.nan], dtype=np.float64)
         assert np.nan in index
 
     def test_contains_float64_not_nans(self):
-        index = Float64Index([1.0, 2.0, np.nan])
+        index = Index([1.0, 2.0, np.nan], dtype=np.float64)
         assert 1.0 in index
 
 
@@ -565,20 +597,15 @@ class TestSliceLocs:
 
 
 class TestGetSliceBounds:
-    @pytest.mark.parametrize("kind", ["getitem", "loc", None])
     @pytest.mark.parametrize("side, expected", [("left", 4), ("right", 5)])
-    def test_get_slice_bounds_within(self, kind, side, expected):
+    def test_get_slice_bounds_within(self, side, expected):
         index = Index(range(6))
-        with tm.assert_produces_warning(FutureWarning, match="'kind' argument"):
-
-            result = index.get_slice_bound(4, kind=kind, side=side)
+        result = index.get_slice_bound(4, side=side)
         assert result == expected
 
-    @pytest.mark.parametrize("kind", ["getitem", "loc", None])
     @pytest.mark.parametrize("side", ["left", "right"])
     @pytest.mark.parametrize("bound, expected", [(-1, 0), (10, 6)])
-    def test_get_slice_bounds_outside(self, kind, side, expected, bound):
+    def test_get_slice_bounds_outside(self, side, expected, bound):
         index = Index(range(6))
-        with tm.assert_produces_warning(FutureWarning, match="'kind' argument"):
-            result = index.get_slice_bound(bound, kind=kind, side=side)
+        result = index.get_slice_bound(bound, side=side)
         assert result == expected
