@@ -28,7 +28,9 @@ class TestEmptyFrameSetitemExpansion:
 
         df["series"] = series
         expected = DataFrame(
-            {"series": [1.23] * 4}, index=pd.RangeIndex(4, name="df_index")
+            {"series": [1.23] * 4},
+            index=pd.RangeIndex(4, name="df_index"),
+            columns=Index(["series"], dtype=object),
         )
 
         tm.assert_frame_equal(df, expected)
@@ -39,7 +41,9 @@ class TestEmptyFrameSetitemExpansion:
         series = Series(1.23, index=pd.RangeIndex(4, name="series_index"))
         df["series"] = series
         expected = DataFrame(
-            {"series": [1.23] * 4}, index=pd.RangeIndex(4, name="series_index")
+            {"series": [1.23] * 4},
+            index=pd.RangeIndex(4, name="series_index"),
+            columns=Index(["series"], dtype=object),
         )
         tm.assert_frame_equal(df, expected)
 
@@ -72,7 +76,6 @@ class TestEmptyFrameSetitemExpansion:
         tm.assert_frame_equal(df, exp)
 
     def test_partial_set_empty_frame(self):
-
         # partially set with an empty object
         # frame
         df = DataFrame()
@@ -93,25 +96,29 @@ class TestEmptyFrameSetitemExpansion:
         # these work as they don't really change
         # anything but the index
         # GH#5632
-        expected = DataFrame(columns=["foo"], index=Index([], dtype="object"))
+        expected = DataFrame(
+            columns=Index(["foo"], dtype=object), index=Index([], dtype="object")
+        )
 
         df = DataFrame(index=Index([], dtype="object"))
         df["foo"] = Series([], dtype="object")
 
         tm.assert_frame_equal(df, expected)
 
-        df = DataFrame()
+        df = DataFrame(index=Index([]))
         df["foo"] = Series(df.index)
 
         tm.assert_frame_equal(df, expected)
 
-        df = DataFrame()
+        df = DataFrame(index=Index([]))
         df["foo"] = df.index
 
         tm.assert_frame_equal(df, expected)
 
     def test_partial_set_empty_frame3(self):
-        expected = DataFrame(columns=["foo"], index=Index([], dtype="int64"))
+        expected = DataFrame(
+            columns=Index(["foo"], dtype=object), index=Index([], dtype="int64")
+        )
         expected["foo"] = expected["foo"].astype("float64")
 
         df = DataFrame(index=Index([], dtype="int64"))
@@ -128,14 +135,16 @@ class TestEmptyFrameSetitemExpansion:
         df = DataFrame(index=Index([], dtype="int64"))
         df["foo"] = range(len(df))
 
-        expected = DataFrame(columns=["foo"], index=Index([], dtype="int64"))
+        expected = DataFrame(
+            columns=Index(["foo"], dtype=object), index=Index([], dtype="int64")
+        )
         # range is int-dtype-like, so we get int64 dtype
         expected["foo"] = expected["foo"].astype("int64")
         tm.assert_frame_equal(df, expected)
 
     def test_partial_set_empty_frame5(self):
         df = DataFrame()
-        tm.assert_index_equal(df.columns, Index([], dtype=object))
+        tm.assert_index_equal(df.columns, pd.RangeIndex(0))
         df2 = DataFrame()
         df2[1] = Series([1], index=["foo"])
         df.loc[:, 1] = Series([1], index=["foo"])
@@ -148,14 +157,10 @@ class TestEmptyFrameSetitemExpansion:
 
         df = DataFrame(columns=["A", "B"])
         df[0] = Series(1, index=range(4))
-        df.dtypes
-        str(df)
         tm.assert_frame_equal(df, expected)
 
         df = DataFrame(columns=["A", "B"])
         df.loc[:, 0] = Series(1, index=range(4))
-        df.dtypes
-        str(df)
         tm.assert_frame_equal(df, expected)
 
     def test_partial_set_empty_frame_row(self):
@@ -182,7 +187,7 @@ class TestEmptyFrameSetitemExpansion:
         df = DataFrame({"A": [1, 2, 3], "B": [1.2, 4.2, 5.2]})
         y = df[df.A > 5]
         result = y.reindex(columns=["A", "B", "C"])
-        expected = DataFrame(columns=["A", "B", "C"], index=Index([], dtype="int64"))
+        expected = DataFrame(columns=["A", "B", "C"])
         expected["A"] = expected["A"].astype("int64")
         expected["B"] = expected["B"].astype("float64")
         expected["C"] = expected["C"].astype("float64")
@@ -205,10 +210,10 @@ class TestEmptyFrameSetitemExpansion:
         df = DataFrame(index=[0])
         df = df.copy()
         df["a"] = 0
-        expected = DataFrame(0, index=[0], columns=["a"])
+        expected = DataFrame(0, index=[0], columns=Index(["a"], dtype=object))
         tm.assert_frame_equal(df, expected)
 
-    def test_partial_set_empty_frame_empty_consistencies(self):
+    def test_partial_set_empty_frame_empty_consistencies(self, using_infer_string):
         # GH#6171
         # consistency on empty frames
         df = DataFrame(columns=["x", "y"])
@@ -218,7 +223,15 @@ class TestEmptyFrameSetitemExpansion:
 
         df = DataFrame(columns=["x", "y"])
         df["x"] = ["1", "2"]
-        expected = DataFrame({"x": ["1", "2"], "y": [np.nan, np.nan]}, dtype=object)
+        expected = DataFrame(
+            {
+                "x": Series(
+                    ["1", "2"],
+                    dtype=object if not using_infer_string else "string[pyarrow_numpy]",
+                ),
+                "y": Series([np.nan, np.nan], dtype=object),
+            }
+        )
         tm.assert_frame_equal(df, expected)
 
         df = DataFrame(columns=["x", "y"])
@@ -229,7 +242,6 @@ class TestEmptyFrameSetitemExpansion:
 
 class TestPartialSetting:
     def test_partial_setting(self):
-
         # GH2578, allow ix and friends to partially set
 
         # series
@@ -266,6 +278,7 @@ class TestPartialSetting:
         with pytest.raises(IndexError, match=msg):
             s.iat[3] = 5.0
 
+    @pytest.mark.filterwarnings("ignore:Setting a value on a view:FutureWarning")
     def test_partial_setting_frame(self, using_array_manager):
         df_orig = DataFrame(
             np.arange(6).reshape(3, 2), columns=["A", "B"], dtype="int64"
@@ -285,35 +298,35 @@ class TestPartialSetting:
             df.iat[4, 2] = 5.0
 
         # row setting where it exists
-        expected = DataFrame(dict({"A": [0, 4, 4], "B": [1, 5, 5]}))
+        expected = DataFrame({"A": [0, 4, 4], "B": [1, 5, 5]})
         df = df_orig.copy()
         df.iloc[1] = df.iloc[2]
         tm.assert_frame_equal(df, expected)
 
-        expected = DataFrame(dict({"A": [0, 4, 4], "B": [1, 5, 5]}))
+        expected = DataFrame({"A": [0, 4, 4], "B": [1, 5, 5]})
         df = df_orig.copy()
         df.loc[1] = df.loc[2]
         tm.assert_frame_equal(df, expected)
 
         # like 2578, partial setting with dtype preservation
-        expected = DataFrame(dict({"A": [0, 2, 4, 4], "B": [1, 3, 5, 5]}))
+        expected = DataFrame({"A": [0, 2, 4, 4], "B": [1, 3, 5, 5]})
         df = df_orig.copy()
         df.loc[3] = df.loc[2]
         tm.assert_frame_equal(df, expected)
 
         # single dtype frame, overwrite
-        expected = DataFrame(dict({"A": [0, 2, 4], "B": [0, 2, 4]}))
+        expected = DataFrame({"A": [0, 2, 4], "B": [0, 2, 4]})
         df = df_orig.copy()
         df.loc[:, "B"] = df.loc[:, "A"]
         tm.assert_frame_equal(df, expected)
 
         # mixed dtype frame, overwrite
-        expected = DataFrame(dict({"A": [0, 2, 4], "B": Series([0, 2, 4])}))
+        expected = DataFrame({"A": [0, 2, 4], "B": Series([0.0, 2.0, 4.0])})
         df = df_orig.copy()
         df["B"] = df["B"].astype(np.float64)
-        msg = "will attempt to set the values inplace instead"
-        with tm.assert_produces_warning(DeprecationWarning, match=msg):
-            df.loc[:, "B"] = df.loc[:, "A"]
+        # as of 2.0, df.loc[:, "B"] = ... attempts (and here succeeds) at
+        #  setting inplace
+        df.loc[:, "B"] = df.loc[:, "A"]
         tm.assert_frame_equal(df, expected)
 
         # single dtype frame, partial setting
@@ -334,7 +347,9 @@ class TestPartialSetting:
         # GH 8473
         dates = date_range("1/1/2000", periods=8)
         df_orig = DataFrame(
-            np.random.randn(8, 4), index=dates, columns=["A", "B", "C", "D"]
+            np.random.default_rng(2).standard_normal((8, 4)),
+            index=dates,
+            columns=["A", "B", "C", "D"],
         )
 
         expected = pd.concat(
@@ -358,7 +373,6 @@ class TestPartialSetting:
         tm.assert_frame_equal(df, expected)
 
     def test_partial_setting_mixed_dtype(self):
-
         # in a mixed dtype environment, try to preserve dtypes
         # by appending
         df = DataFrame([[True, 1], [False, 2]], columns=["female", "fitness"])
@@ -403,8 +417,8 @@ class TestPartialSetting:
 
         # raises as nothing is in the index
         msg = (
-            r"\"None of \[Int64Index\(\[3, 3, 3\], dtype='int64'\)\] are "
-            r"in the \[index\]\""
+            rf"\"None of \[Index\(\[3, 3, 3\], dtype='{np.dtype(int)}'\)\] "
+            r"are in the \[index\]\""
         )
         with pytest.raises(KeyError, match=msg):
             ser.loc[[3, 3, 3]]
@@ -484,7 +498,7 @@ class TestPartialSetting:
 
         # raises as nothing is in the index
         msg = (
-            r"\"None of \[Int64Index\(\[3, 3, 3\], dtype='int64', "
+            rf"\"None of \[Index\(\[3, 3, 3\], dtype='{np.dtype(int)}', "
             r"name='idx'\)\] are in the \[index\]\""
         )
         with pytest.raises(KeyError, match=msg):
@@ -522,7 +536,11 @@ class TestPartialSetting:
     @pytest.mark.parametrize("key", [100, 100.0])
     def test_setitem_with_expansion_numeric_into_datetimeindex(self, key):
         # GH#4940 inserting non-strings
-        orig = tm.makeTimeDataFrame()
+        orig = DataFrame(
+            np.random.default_rng(2).standard_normal((10, 4)),
+            columns=Index(list("ABCD"), dtype=object),
+            index=date_range("2000-01-01", periods=10, freq="B"),
+        )
         df = orig.copy()
 
         df.loc[key, :] = df.iloc[0]
@@ -533,11 +551,14 @@ class TestPartialSetting:
         tm.assert_frame_equal(df, expected)
 
     def test_partial_set_invalid(self):
-
         # GH 4940
         # allow only setting of 'valid' values
 
-        orig = tm.makeTimeDataFrame()
+        orig = DataFrame(
+            np.random.default_rng(2).standard_normal((10, 4)),
+            columns=Index(list("ABCD"), dtype=object),
+            index=date_range("2000-01-01", periods=10, freq="B"),
+        )
 
         # allow object conversion here
         df = orig.copy()
@@ -623,7 +644,7 @@ class TestPartialSetting:
         [
             (
                 period_range(start="2000", periods=20, freq="D"),
-                ["4D", "8D"],
+                Index(["4D", "8D"], dtype=object),
                 (
                     r"None of \[Index\(\['4D', '8D'\], dtype='object'\)\] "
                     r"are in the \[index\]"
@@ -631,7 +652,7 @@ class TestPartialSetting:
             ),
             (
                 date_range(start="2000", periods=20, freq="D"),
-                ["4D", "8D"],
+                Index(["4D", "8D"], dtype=object),
                 (
                     r"None of \[Index\(\['4D', '8D'\], dtype='object'\)\] "
                     r"are in the \[index\]"
@@ -639,7 +660,7 @@ class TestPartialSetting:
             ),
             (
                 pd.timedelta_range(start="1 day", periods=20),
-                ["2000-01-04", "2000-01-08"],
+                Index(["2000-01-04", "2000-01-08"], dtype=object),
                 (
                     r"None of \[Index\(\['2000-01-04', '2000-01-08'\], "
                     r"dtype='object'\)\] are in the \[index\]"
@@ -668,5 +689,14 @@ class TestStringSlicing:
         index = pd.to_datetime(["2012-01-01", "2012-01-02", "2012-01-03", None])
         df = DataFrame(range(len(index)), index=index)
         expected = DataFrame(range(len(index[:3])), index=index[:3])
-        result = df["2012-01-01":"2012-01-04"]
+        with pytest.raises(KeyError, match="non-existing keys is not allowed"):
+            # Upper bound is not in index (which is unordered)
+            # GH53983
+            # GH37819
+            df["2012-01-01":"2012-01-04"]
+        # Need this precision for right bound since the right slice
+        # bound is "rounded" up to the largest timepoint smaller than
+        # the next "resolution"-step of the provided point.
+        # e.g. 2012-01-03 is rounded up to 2012-01-04 - 1ns
+        result = df["2012-01-01":"2012-01-03 00:00:00.000000000"]
         tm.assert_frame_equal(result, expected)
