@@ -1,6 +1,4 @@
 from functools import partial
-import operator
-import warnings
 
 import numpy as np
 import pytest
@@ -15,37 +13,194 @@ from pandas import (
     isna,
 )
 import pandas._testing as tm
-from pandas.core.arrays import DatetimeArray
-import pandas.core.nanops as nanops
+from pandas.core import nanops
 
 use_bn = nanops._USE_BOTTLENECK
-has_c16 = hasattr(np, "complex128")
 
 
-@pytest.fixture(params=[True, False])
-def skipna(request):
-    """
-    Fixture to pass skipna to nanops functions.
-    """
-    return request.param
+@pytest.fixture
+def disable_bottleneck(monkeypatch):
+    with monkeypatch.context() as m:
+        m.setattr(nanops, "_USE_BOTTLENECK", False)
+        yield
+
+
+@pytest.fixture
+def arr_shape():
+    return 11, 7
+
+
+@pytest.fixture
+def arr_float(arr_shape):
+    return np.random.default_rng(2).standard_normal(arr_shape)
+
+
+@pytest.fixture
+def arr_complex(arr_float):
+    return arr_float + arr_float * 1j
+
+
+@pytest.fixture
+def arr_int(arr_shape):
+    return np.random.default_rng(2).integers(-10, 10, arr_shape)
+
+
+@pytest.fixture
+def arr_bool(arr_shape):
+    return np.random.default_rng(2).integers(0, 2, arr_shape) == 0
+
+
+@pytest.fixture
+def arr_str(arr_float):
+    return np.abs(arr_float).astype("S")
+
+
+@pytest.fixture
+def arr_utf(arr_float):
+    return np.abs(arr_float).astype("U")
+
+
+@pytest.fixture
+def arr_date(arr_shape):
+    return np.random.default_rng(2).integers(0, 20000, arr_shape).astype("M8[ns]")
+
+
+@pytest.fixture
+def arr_tdelta(arr_shape):
+    return np.random.default_rng(2).integers(0, 20000, arr_shape).astype("m8[ns]")
+
+
+@pytest.fixture
+def arr_nan(arr_shape):
+    return np.tile(np.nan, arr_shape)
+
+
+@pytest.fixture
+def arr_float_nan(arr_float, arr_nan):
+    return np.vstack([arr_float, arr_nan])
+
+
+@pytest.fixture
+def arr_nan_float1(arr_nan, arr_float):
+    return np.vstack([arr_nan, arr_float])
+
+
+@pytest.fixture
+def arr_nan_nan(arr_nan):
+    return np.vstack([arr_nan, arr_nan])
+
+
+@pytest.fixture
+def arr_inf(arr_float):
+    return arr_float * np.inf
+
+
+@pytest.fixture
+def arr_float_inf(arr_float, arr_inf):
+    return np.vstack([arr_float, arr_inf])
+
+
+@pytest.fixture
+def arr_nan_inf(arr_nan, arr_inf):
+    return np.vstack([arr_nan, arr_inf])
+
+
+@pytest.fixture
+def arr_float_nan_inf(arr_float, arr_nan, arr_inf):
+    return np.vstack([arr_float, arr_nan, arr_inf])
+
+
+@pytest.fixture
+def arr_nan_nan_inf(arr_nan, arr_inf):
+    return np.vstack([arr_nan, arr_nan, arr_inf])
+
+
+@pytest.fixture
+def arr_obj(
+    arr_float, arr_int, arr_bool, arr_complex, arr_str, arr_utf, arr_date, arr_tdelta
+):
+    return np.vstack(
+        [
+            arr_float.astype("O"),
+            arr_int.astype("O"),
+            arr_bool.astype("O"),
+            arr_complex.astype("O"),
+            arr_str.astype("O"),
+            arr_utf.astype("O"),
+            arr_date.astype("O"),
+            arr_tdelta.astype("O"),
+        ]
+    )
+
+
+@pytest.fixture
+def arr_nan_nanj(arr_nan):
+    with np.errstate(invalid="ignore"):
+        return arr_nan + arr_nan * 1j
+
+
+@pytest.fixture
+def arr_complex_nan(arr_complex, arr_nan_nanj):
+    with np.errstate(invalid="ignore"):
+        return np.vstack([arr_complex, arr_nan_nanj])
+
+
+@pytest.fixture
+def arr_nan_infj(arr_inf):
+    with np.errstate(invalid="ignore"):
+        return arr_inf * 1j
+
+
+@pytest.fixture
+def arr_complex_nan_infj(arr_complex, arr_nan_infj):
+    with np.errstate(invalid="ignore"):
+        return np.vstack([arr_complex, arr_nan_infj])
+
+
+@pytest.fixture
+def arr_float_1d(arr_float):
+    return arr_float[:, 0]
+
+
+@pytest.fixture
+def arr_nan_1d(arr_nan):
+    return arr_nan[:, 0]
+
+
+@pytest.fixture
+def arr_float_nan_1d(arr_float_nan):
+    return arr_float_nan[:, 0]
+
+
+@pytest.fixture
+def arr_float1_nan_1d(arr_float1_nan):
+    return arr_float1_nan[:, 0]
+
+
+@pytest.fixture
+def arr_nan_float1_1d(arr_nan_float1):
+    return arr_nan_float1[:, 0]
 
 
 class TestnanopsDataFrame:
-    def setup_method(self, method):
-        np.random.seed(11235)
+    def setup_method(self):
         nanops._USE_BOTTLENECK = False
 
         arr_shape = (11, 7)
 
-        self.arr_float = np.random.randn(*arr_shape)
-        self.arr_float1 = np.random.randn(*arr_shape)
+        self.arr_float = np.random.default_rng(2).standard_normal(arr_shape)
+        self.arr_float1 = np.random.default_rng(2).standard_normal(arr_shape)
         self.arr_complex = self.arr_float + self.arr_float1 * 1j
-        self.arr_int = np.random.randint(-10, 10, arr_shape)
-        self.arr_bool = np.random.randint(0, 2, arr_shape) == 0
+        self.arr_int = np.random.default_rng(2).integers(-10, 10, arr_shape)
+        self.arr_bool = np.random.default_rng(2).integers(0, 2, arr_shape) == 0
         self.arr_str = np.abs(self.arr_float).astype("S")
         self.arr_utf = np.abs(self.arr_float).astype("U")
-        self.arr_date = np.random.randint(0, 20000, arr_shape).astype("M8[ns]")
-        self.arr_tdelta = np.random.randint(0, 20000, arr_shape).astype("m8[ns]")
+        self.arr_date = (
+            np.random.default_rng(2).integers(0, 20000, arr_shape).astype("M8[ns]")
+        )
+        self.arr_tdelta = (
+            np.random.default_rng(2).integers(0, 20000, arr_shape).astype("m8[ns]")
+        )
 
         self.arr_nan = np.tile(np.nan, arr_shape)
         self.arr_float_nan = np.vstack([self.arr_float, self.arr_nan])
@@ -95,7 +250,7 @@ class TestnanopsDataFrame:
         self.arr_float1_nan_1d = self.arr_float1_nan[:, 0]
         self.arr_nan_float1_1d = self.arr_nan_float1[:, 0]
 
-    def teardown_method(self, method):
+    def teardown_method(self):
         nanops._USE_BOTTLENECK = use_bn
 
     def check_results(self, targ, res, axis, check_dtype=True):
@@ -112,7 +267,6 @@ class TestnanopsDataFrame:
         try:
             tm.assert_almost_equal(targ, res, check_dtype=check_dtype)
         except AssertionError:
-
             # handle timedelta dtypes
             if hasattr(targ, "dtype") and targ.dtype == "m8[ns]":
                 raise
@@ -128,7 +282,7 @@ class TestnanopsDataFrame:
                 if targ.dtype.kind != "O":
                     res = res.astype(targ.dtype)
                 else:
-                    cast_dtype = "c16" if has_c16 else "f8"
+                    cast_dtype = "c16" if hasattr(np, "complex128") else "f8"
                     res = res.astype(cast_dtype)
                     targ = targ.astype(cast_dtype)
             # there should never be a case where numpy returns an object
@@ -166,6 +320,16 @@ class TestnanopsDataFrame:
                     targ = bool(targ)
 
             res = testfunc(testarval, axis=axis, skipna=skipna, **kwargs)
+
+            if (
+                isinstance(targ, np.complex128)
+                and isinstance(res, float)
+                and np.isnan(targ)
+                and np.isnan(res)
+            ):
+                # GH#18463
+                targ = res
+
             self.check_results(targ, res, axis, check_dtype=check_dtype)
             if skipna:
                 res = testfunc(testarval, axis=axis, **kwargs)
@@ -197,7 +361,6 @@ class TestnanopsDataFrame:
     def check_fun(
         self, testfunc, targfunc, testar, skipna, empty_targfunc=None, **kwargs
     ):
-
         targar = testar
         if testar.endswith("_nan") and hasattr(self, testar[:-4]):
             targar = testar[:-4]
@@ -300,56 +463,16 @@ class TestnanopsDataFrame:
             nanops.nanmean, np.mean, skipna, allow_obj=False, allow_date=False
         )
 
-    def test_nanmean_overflow(self):
-        # GH 10155
-        # In the previous implementation mean can overflow for int dtypes, it
-        # is now consistent with numpy
-
-        for a in [2**55, -(2**55), 20150515061816532]:
-            s = Series(a, index=range(500), dtype=np.int64)
-            result = s.mean()
-            np_result = s.values.mean()
-            assert result == a
-            assert result == np_result
-            assert result.dtype == np.float64
-
-    @pytest.mark.parametrize(
-        "dtype",
-        [
-            np.int16,
-            np.int32,
-            np.int64,
-            np.float32,
-            np.float64,
-            getattr(np, "float128", None),
-        ],
-    )
-    def test_returned_dtype(self, dtype):
-        if dtype is None:
-            # no float128 available
-            return
-
-        s = Series(range(10), dtype=dtype)
-        group_a = ["mean", "std", "var", "skew", "kurt"]
-        group_b = ["min", "max"]
-        for method in group_a + group_b:
-            result = getattr(s, method)()
-            if is_integer_dtype(dtype) and method in group_a:
-                assert result.dtype == np.float64
-            else:
-                assert result.dtype == dtype
-
+    @pytest.mark.filterwarnings("ignore::RuntimeWarning")
     def test_nanmedian(self, skipna):
-        with warnings.catch_warnings(record=True):
-            warnings.simplefilter("ignore", RuntimeWarning)
-            self.check_funs(
-                nanops.nanmedian,
-                np.median,
-                skipna,
-                allow_complex=False,
-                allow_date=False,
-                allow_obj="convert",
-            )
+        self.check_funs(
+            nanops.nanmedian,
+            np.median,
+            skipna,
+            allow_complex=False,
+            allow_date=False,
+            allow_obj="convert",
+        )
 
     @pytest.mark.parametrize("ddof", range(3))
     def test_nanvar(self, ddof, skipna):
@@ -375,15 +498,14 @@ class TestnanopsDataFrame:
             ddof=ddof,
         )
 
-    @td.skip_if_no_scipy
     @pytest.mark.parametrize("ddof", range(3))
     def test_nansem(self, ddof, skipna):
-        from scipy.stats import sem
+        sp_stats = pytest.importorskip("scipy.stats")
 
         with np.errstate(invalid="ignore"):
             self.check_funs(
                 nanops.nansem,
-                sem,
+                sp_stats.sem,
                 skipna,
                 allow_complex=False,
                 allow_date=False,
@@ -392,13 +514,12 @@ class TestnanopsDataFrame:
                 ddof=ddof,
             )
 
+    @pytest.mark.filterwarnings("ignore::RuntimeWarning")
     @pytest.mark.parametrize(
         "nan_op,np_op", [(nanops.nanmin, np.min), (nanops.nanmax, np.max)]
     )
     def test_nanops_with_warnings(self, nan_op, np_op, skipna):
-        with warnings.catch_warnings(record=True):
-            warnings.simplefilter("ignore", RuntimeWarning)
-            self.check_funs(nan_op, np_op, skipna, allow_obj=False)
+        self.check_funs(nan_op, np_op, skipna, allow_obj=False)
 
     def _argminmax_wrap(self, value, axis=None, func=None):
         res = func(value, axis)
@@ -415,17 +536,15 @@ class TestnanopsDataFrame:
             res = -1
         return res
 
+    @pytest.mark.filterwarnings("ignore::RuntimeWarning")
     def test_nanargmax(self, skipna):
-        with warnings.catch_warnings(record=True):
-            warnings.simplefilter("ignore", RuntimeWarning)
-            func = partial(self._argminmax_wrap, func=np.argmax)
-            self.check_funs(nanops.nanargmax, func, skipna, allow_obj=False)
+        func = partial(self._argminmax_wrap, func=np.argmax)
+        self.check_funs(nanops.nanargmax, func, skipna, allow_obj=False)
 
+    @pytest.mark.filterwarnings("ignore::RuntimeWarning")
     def test_nanargmin(self, skipna):
-        with warnings.catch_warnings(record=True):
-            warnings.simplefilter("ignore", RuntimeWarning)
-            func = partial(self._argminmax_wrap, func=np.argmin)
-            self.check_funs(nanops.nanargmin, func, skipna, allow_obj=False)
+        func = partial(self._argminmax_wrap, func=np.argmin)
+        self.check_funs(nanops.nanargmin, func, skipna, allow_obj=False)
 
     def _skew_kurt_wrap(self, values, axis=None, func=None):
         if not isinstance(values.dtype.type, np.floating):
@@ -439,11 +558,10 @@ class TestnanopsDataFrame:
             return 0.0
         return result
 
-    @td.skip_if_no_scipy
     def test_nanskew(self, skipna):
-        from scipy.stats import skew
+        sp_stats = pytest.importorskip("scipy.stats")
 
-        func = partial(self._skew_kurt_wrap, func=skew)
+        func = partial(self._skew_kurt_wrap, func=sp_stats.skew)
         with np.errstate(invalid="ignore"):
             self.check_funs(
                 nanops.nanskew,
@@ -454,11 +572,10 @@ class TestnanopsDataFrame:
                 allow_tdelta=False,
             )
 
-    @td.skip_if_no_scipy
     def test_nankurt(self, skipna):
-        from scipy.stats import kurtosis
+        sp_stats = pytest.importorskip("scipy.stats")
 
-        func1 = partial(kurtosis, fisher=True)
+        func1 = partial(sp_stats.kurtosis, fisher=True)
         func = partial(self._skew_kurt_wrap, func=func1)
         with np.errstate(invalid="ignore"):
             self.check_funs(
@@ -586,30 +703,28 @@ class TestnanopsDataFrame:
         targ1 = np.corrcoef(self.arr_float_1d.flat, self.arr_float1_1d.flat)[0, 1]
         self.check_nancorr_nancov_1d(nanops.nancorr, targ0, targ1, method="pearson")
 
-    @td.skip_if_no_scipy
     def test_nancorr_kendall(self):
-        from scipy.stats import kendalltau
+        sp_stats = pytest.importorskip("scipy.stats")
 
-        targ0 = kendalltau(self.arr_float_2d, self.arr_float1_2d)[0]
-        targ1 = kendalltau(self.arr_float_2d.flat, self.arr_float1_2d.flat)[0]
+        targ0 = sp_stats.kendalltau(self.arr_float_2d, self.arr_float1_2d)[0]
+        targ1 = sp_stats.kendalltau(self.arr_float_2d.flat, self.arr_float1_2d.flat)[0]
         self.check_nancorr_nancov_2d(nanops.nancorr, targ0, targ1, method="kendall")
-        targ0 = kendalltau(self.arr_float_1d, self.arr_float1_1d)[0]
-        targ1 = kendalltau(self.arr_float_1d.flat, self.arr_float1_1d.flat)[0]
+        targ0 = sp_stats.kendalltau(self.arr_float_1d, self.arr_float1_1d)[0]
+        targ1 = sp_stats.kendalltau(self.arr_float_1d.flat, self.arr_float1_1d.flat)[0]
         self.check_nancorr_nancov_1d(nanops.nancorr, targ0, targ1, method="kendall")
 
-    @td.skip_if_no_scipy
     def test_nancorr_spearman(self):
-        from scipy.stats import spearmanr
+        sp_stats = pytest.importorskip("scipy.stats")
 
-        targ0 = spearmanr(self.arr_float_2d, self.arr_float1_2d)[0]
-        targ1 = spearmanr(self.arr_float_2d.flat, self.arr_float1_2d.flat)[0]
+        targ0 = sp_stats.spearmanr(self.arr_float_2d, self.arr_float1_2d)[0]
+        targ1 = sp_stats.spearmanr(self.arr_float_2d.flat, self.arr_float1_2d.flat)[0]
         self.check_nancorr_nancov_2d(nanops.nancorr, targ0, targ1, method="spearman")
-        targ0 = spearmanr(self.arr_float_1d, self.arr_float1_1d)[0]
-        targ1 = spearmanr(self.arr_float_1d.flat, self.arr_float1_1d.flat)[0]
+        targ0 = sp_stats.spearmanr(self.arr_float_1d, self.arr_float1_1d)[0]
+        targ1 = sp_stats.spearmanr(self.arr_float_1d.flat, self.arr_float1_1d.flat)[0]
         self.check_nancorr_nancov_1d(nanops.nancorr, targ0, targ1, method="spearman")
 
-    @td.skip_if_no_scipy
     def test_invalid_method(self):
+        pytest.importorskip("scipy")
         targ0 = np.corrcoef(self.arr_float_2d, self.arr_float1_2d)[0, 1]
         targ1 = np.corrcoef(self.arr_float_2d.flat, self.arr_float1_2d.flat)[0, 1]
         msg = "Unknown method 'foo', expected one of 'kendall', 'spearman'"
@@ -624,114 +739,90 @@ class TestnanopsDataFrame:
         targ1 = np.cov(self.arr_float_1d.flat, self.arr_float1_1d.flat)[0, 1]
         self.check_nancorr_nancov_1d(nanops.nancov, targ0, targ1)
 
-    def check_nancomp(self, checkfun, targ0):
-        arr_float = self.arr_float
-        arr_float1 = self.arr_float1
-        arr_nan = self.arr_nan
-        arr_nan_nan = self.arr_nan_nan
-        arr_float_nan = self.arr_float_nan
-        arr_float1_nan = self.arr_float1_nan
-        arr_nan_float1 = self.arr_nan_float1
 
-        while targ0.ndim:
-            res0 = checkfun(arr_float, arr_float1)
-            tm.assert_almost_equal(targ0, res0)
+@pytest.mark.parametrize(
+    "arr, correct",
+    [
+        ("arr_complex", False),
+        ("arr_int", False),
+        ("arr_bool", False),
+        ("arr_str", False),
+        ("arr_utf", False),
+        ("arr_complex", False),
+        ("arr_complex_nan", False),
+        ("arr_nan_nanj", False),
+        ("arr_nan_infj", True),
+        ("arr_complex_nan_infj", True),
+    ],
+)
+def test_has_infs_non_float(request, arr, correct, disable_bottleneck):
+    val = request.getfixturevalue(arr)
+    while getattr(val, "ndim", True):
+        res0 = nanops._has_infs(val)
+        if correct:
+            assert res0
+        else:
+            assert not res0
 
-            if targ0.ndim > 1:
-                targ1 = np.vstack([targ0, arr_nan])
-            else:
-                targ1 = np.hstack([targ0, arr_nan])
-            res1 = checkfun(arr_float_nan, arr_float1_nan)
-            tm.assert_numpy_array_equal(targ1, res1, check_dtype=False)
+        if not hasattr(val, "ndim"):
+            break
 
-            targ2 = arr_nan_nan
-            res2 = checkfun(arr_float_nan, arr_nan_float1)
-            tm.assert_numpy_array_equal(targ2, res2, check_dtype=False)
+        # Reduce dimension for next step in the loop
+        val = np.take(val, 0, axis=-1)
 
-            # Lower dimension for next step in the loop
-            arr_float = np.take(arr_float, 0, axis=-1)
-            arr_float1 = np.take(arr_float1, 0, axis=-1)
-            arr_nan = np.take(arr_nan, 0, axis=-1)
-            arr_nan_nan = np.take(arr_nan_nan, 0, axis=-1)
-            arr_float_nan = np.take(arr_float_nan, 0, axis=-1)
-            arr_float1_nan = np.take(arr_float1_nan, 0, axis=-1)
-            arr_nan_float1 = np.take(arr_nan_float1, 0, axis=-1)
-            targ0 = np.take(targ0, 0, axis=-1)
 
-    @pytest.mark.parametrize(
-        "op,nanop",
-        [
-            (operator.eq, nanops.naneq),
-            (operator.ne, nanops.nanne),
-            (operator.gt, nanops.nangt),
-            (operator.ge, nanops.nange),
-            (operator.lt, nanops.nanlt),
-            (operator.le, nanops.nanle),
-        ],
-    )
-    def test_nan_comparison(self, op, nanop):
-        targ0 = op(self.arr_float, self.arr_float1)
-        self.check_nancomp(nanop, targ0)
+@pytest.mark.parametrize(
+    "arr, correct",
+    [
+        ("arr_float", False),
+        ("arr_nan", False),
+        ("arr_float_nan", False),
+        ("arr_nan_nan", False),
+        ("arr_float_inf", True),
+        ("arr_inf", True),
+        ("arr_nan_inf", True),
+        ("arr_float_nan_inf", True),
+        ("arr_nan_nan_inf", True),
+    ],
+)
+@pytest.mark.parametrize("astype", [None, "f4", "f2"])
+def test_has_infs_floats(request, arr, correct, astype, disable_bottleneck):
+    val = request.getfixturevalue(arr)
+    if astype is not None:
+        val = val.astype(astype)
+    while getattr(val, "ndim", True):
+        res0 = nanops._has_infs(val)
+        if correct:
+            assert res0
+        else:
+            assert not res0
 
-    def check_bool(self, func, value, correct):
-        while getattr(value, "ndim", True):
-            res0 = func(value)
-            if correct:
-                assert res0
-            else:
-                assert not res0
+        if not hasattr(val, "ndim"):
+            break
 
-            if not hasattr(value, "ndim"):
-                break
+        # Reduce dimension for next step in the loop
+        val = np.take(val, 0, axis=-1)
 
-            # Reduce dimension for next step in the loop
-            value = np.take(value, 0, axis=-1)
 
-    def test__has_infs(self):
-        pairs = [
-            ("arr_complex", False),
-            ("arr_int", False),
-            ("arr_bool", False),
-            ("arr_str", False),
-            ("arr_utf", False),
-            ("arr_complex", False),
-            ("arr_complex_nan", False),
-            ("arr_nan_nanj", False),
-            ("arr_nan_infj", True),
-            ("arr_complex_nan_infj", True),
-        ]
-        pairs_float = [
-            ("arr_float", False),
-            ("arr_nan", False),
-            ("arr_float_nan", False),
-            ("arr_nan_nan", False),
-            ("arr_float_inf", True),
-            ("arr_inf", True),
-            ("arr_nan_inf", True),
-            ("arr_float_nan_inf", True),
-            ("arr_nan_nan_inf", True),
-        ]
+@pytest.mark.parametrize(
+    "fixture", ["arr_float", "arr_complex", "arr_int", "arr_bool", "arr_str", "arr_utf"]
+)
+def test_bn_ok_dtype(fixture, request, disable_bottleneck):
+    obj = request.getfixturevalue(fixture)
+    assert nanops._bn_ok_dtype(obj.dtype, "test")
 
-        for arr, correct in pairs:
-            val = getattr(self, arr)
-            self.check_bool(nanops._has_infs, val, correct)
 
-        for arr, correct in pairs_float:
-            val = getattr(self, arr)
-            self.check_bool(nanops._has_infs, val, correct)
-            self.check_bool(nanops._has_infs, val.astype("f4"), correct)
-            self.check_bool(nanops._has_infs, val.astype("f2"), correct)
-
-    def test__bn_ok_dtype(self):
-        assert nanops._bn_ok_dtype(self.arr_float.dtype, "test")
-        assert nanops._bn_ok_dtype(self.arr_complex.dtype, "test")
-        assert nanops._bn_ok_dtype(self.arr_int.dtype, "test")
-        assert nanops._bn_ok_dtype(self.arr_bool.dtype, "test")
-        assert nanops._bn_ok_dtype(self.arr_str.dtype, "test")
-        assert nanops._bn_ok_dtype(self.arr_utf.dtype, "test")
-        assert not nanops._bn_ok_dtype(self.arr_date.dtype, "test")
-        assert not nanops._bn_ok_dtype(self.arr_tdelta.dtype, "test")
-        assert not nanops._bn_ok_dtype(self.arr_obj.dtype, "test")
+@pytest.mark.parametrize(
+    "fixture",
+    [
+        "arr_date",
+        "arr_tdelta",
+        "arr_obj",
+    ],
+)
+def test_bn_not_ok_dtype(fixture, request, disable_bottleneck):
+    obj = request.getfixturevalue(fixture)
+    assert not nanops._bn_ok_dtype(obj.dtype, "test")
 
 
 class TestEnsureNumeric:
@@ -756,7 +847,9 @@ class TestEnsureNumeric:
 
         # Test convertible string ndarray
         s_values = np.array(["1", "2", "3"], dtype=object)
-        assert np.allclose(nanops._ensure_numeric(s_values), values)
+        msg = r"Could not convert \['1' '2' '3'\] to numeric"
+        with pytest.raises(TypeError, match=msg):
+            nanops._ensure_numeric(s_values)
 
         # Test non-convertible string ndarray
         s_values = np.array(["foo", "bar", "baz"], dtype=object)
@@ -765,12 +858,19 @@ class TestEnsureNumeric:
             nanops._ensure_numeric(s_values)
 
     def test_convertable_values(self):
-        assert np.allclose(nanops._ensure_numeric("1"), 1.0)
-        assert np.allclose(nanops._ensure_numeric("1.1"), 1.1)
-        assert np.allclose(nanops._ensure_numeric("1+1j"), 1 + 1j)
+        with pytest.raises(TypeError, match="Could not convert string '1' to numeric"):
+            nanops._ensure_numeric("1")
+        with pytest.raises(
+            TypeError, match="Could not convert string '1.1' to numeric"
+        ):
+            nanops._ensure_numeric("1.1")
+        with pytest.raises(
+            TypeError, match=r"Could not convert string '1\+1j' to numeric"
+        ):
+            nanops._ensure_numeric("1+1j")
 
     def test_non_convertable_values(self):
-        msg = "Could not convert foo to numeric"
+        msg = "Could not convert string 'foo' to numeric"
         with pytest.raises(TypeError, match=msg):
             nanops._ensure_numeric("foo")
 
@@ -783,48 +883,48 @@ class TestEnsureNumeric:
 
 
 class TestNanvarFixedValues:
-
     # xref GH10242
+    # Samples from a normal distribution.
+    @pytest.fixture
+    def variance(self):
+        return 3.0
 
-    def setup_method(self, method):
-        # Samples from a normal distribution.
-        self.variance = variance = 3.0
-        self.samples = self.prng.normal(scale=variance**0.5, size=100000)
+    @pytest.fixture
+    def samples(self, variance):
+        return self.prng.normal(scale=variance**0.5, size=100000)
 
-    def test_nanvar_all_finite(self):
-        samples = self.samples
+    def test_nanvar_all_finite(self, samples, variance):
         actual_variance = nanops.nanvar(samples)
-        tm.assert_almost_equal(actual_variance, self.variance, rtol=1e-2)
+        tm.assert_almost_equal(actual_variance, variance, rtol=1e-2)
 
-    def test_nanvar_nans(self):
-        samples = np.nan * np.ones(2 * self.samples.shape[0])
-        samples[::2] = self.samples
+    def test_nanvar_nans(self, samples, variance):
+        samples_test = np.nan * np.ones(2 * samples.shape[0])
+        samples_test[::2] = samples
 
-        actual_variance = nanops.nanvar(samples, skipna=True)
-        tm.assert_almost_equal(actual_variance, self.variance, rtol=1e-2)
+        actual_variance = nanops.nanvar(samples_test, skipna=True)
+        tm.assert_almost_equal(actual_variance, variance, rtol=1e-2)
 
-        actual_variance = nanops.nanvar(samples, skipna=False)
+        actual_variance = nanops.nanvar(samples_test, skipna=False)
         tm.assert_almost_equal(actual_variance, np.nan, rtol=1e-2)
 
-    def test_nanstd_nans(self):
-        samples = np.nan * np.ones(2 * self.samples.shape[0])
-        samples[::2] = self.samples
+    def test_nanstd_nans(self, samples, variance):
+        samples_test = np.nan * np.ones(2 * samples.shape[0])
+        samples_test[::2] = samples
 
-        actual_std = nanops.nanstd(samples, skipna=True)
-        tm.assert_almost_equal(actual_std, self.variance**0.5, rtol=1e-2)
+        actual_std = nanops.nanstd(samples_test, skipna=True)
+        tm.assert_almost_equal(actual_std, variance**0.5, rtol=1e-2)
 
-        actual_std = nanops.nanvar(samples, skipna=False)
+        actual_std = nanops.nanvar(samples_test, skipna=False)
         tm.assert_almost_equal(actual_std, np.nan, rtol=1e-2)
 
-    def test_nanvar_axis(self):
+    def test_nanvar_axis(self, samples, variance):
         # Generate some sample data.
-        samples_norm = self.samples
-        samples_unif = self.prng.uniform(size=samples_norm.shape[0])
-        samples = np.vstack([samples_norm, samples_unif])
+        samples_unif = self.prng.uniform(size=samples.shape[0])
+        samples = np.vstack([samples, samples_unif])
 
         actual_variance = nanops.nanvar(samples, axis=1)
         tm.assert_almost_equal(
-            actual_variance, np.array([self.variance, 1.0 / 12]), rtol=1e-2
+            actual_variance, np.array([variance, 1.0 / 12]), rtol=1e-2
         )
 
     def test_nanvar_ddof(self):
@@ -896,24 +996,26 @@ class TestNanvarFixedValues:
 
     @property
     def prng(self):
-        return np.random.RandomState(1234)
+        return np.random.default_rng(2)
 
 
 class TestNanskewFixedValues:
-
     # xref GH 11974
+    # Test data + skewness value (computed with scipy.stats.skew)
+    @pytest.fixture
+    def samples(self):
+        return np.sin(np.linspace(0, 1, 200))
 
-    def setup_method(self, method):
-        # Test data + skewness value (computed with scipy.stats.skew)
-        self.samples = np.sin(np.linspace(0, 1, 200))
-        self.actual_skew = -0.1875895205961754
+    @pytest.fixture
+    def actual_skew(self):
+        return -0.1875895205961754
 
-    def test_constant_series(self):
+    @pytest.mark.parametrize("val", [3075.2, 3075.3, 3075.5])
+    def test_constant_series(self, val):
         # xref GH 11974
-        for val in [3075.2, 3075.3, 3075.5]:
-            data = val * np.ones(300)
-            skew = nanops.nanskew(data)
-            assert skew == 0.0
+        data = val * np.ones(300)
+        skew = nanops.nanskew(data)
+        assert skew == 0.0
 
     def test_all_finite(self):
         alpha, beta = 0.3, 0.1
@@ -924,38 +1026,40 @@ class TestNanskewFixedValues:
         right_tailed = self.prng.beta(alpha, beta, size=100)
         assert nanops.nanskew(right_tailed) > 0
 
-    def test_ground_truth(self):
-        skew = nanops.nanskew(self.samples)
-        tm.assert_almost_equal(skew, self.actual_skew)
+    def test_ground_truth(self, samples, actual_skew):
+        skew = nanops.nanskew(samples)
+        tm.assert_almost_equal(skew, actual_skew)
 
-    def test_axis(self):
-        samples = np.vstack([self.samples, np.nan * np.ones(len(self.samples))])
+    def test_axis(self, samples, actual_skew):
+        samples = np.vstack([samples, np.nan * np.ones(len(samples))])
         skew = nanops.nanskew(samples, axis=1)
-        tm.assert_almost_equal(skew, np.array([self.actual_skew, np.nan]))
+        tm.assert_almost_equal(skew, np.array([actual_skew, np.nan]))
 
-    def test_nans(self):
-        samples = np.hstack([self.samples, np.nan])
+    def test_nans(self, samples):
+        samples = np.hstack([samples, np.nan])
         skew = nanops.nanskew(samples, skipna=False)
         assert np.isnan(skew)
 
-    def test_nans_skipna(self):
-        samples = np.hstack([self.samples, np.nan])
+    def test_nans_skipna(self, samples, actual_skew):
+        samples = np.hstack([samples, np.nan])
         skew = nanops.nanskew(samples, skipna=True)
-        tm.assert_almost_equal(skew, self.actual_skew)
+        tm.assert_almost_equal(skew, actual_skew)
 
     @property
     def prng(self):
-        return np.random.RandomState(1234)
+        return np.random.default_rng(2)
 
 
 class TestNankurtFixedValues:
-
     # xref GH 11974
+    # Test data + kurtosis value (computed with scipy.stats.kurtosis)
+    @pytest.fixture
+    def samples(self):
+        return np.sin(np.linspace(0, 1, 200))
 
-    def setup_method(self, method):
-        # Test data + kurtosis value (computed with scipy.stats.kurtosis)
-        self.samples = np.sin(np.linspace(0, 1, 200))
-        self.actual_kurt = -1.2058303433799713
+    @pytest.fixture
+    def actual_kurt(self):
+        return -1.2058303433799713
 
     @pytest.mark.parametrize("val", [3075.2, 3075.3, 3075.5])
     def test_constant_series(self, val):
@@ -967,61 +1071,67 @@ class TestNankurtFixedValues:
     def test_all_finite(self):
         alpha, beta = 0.3, 0.1
         left_tailed = self.prng.beta(alpha, beta, size=100)
-        assert nanops.nankurt(left_tailed) < 0
+        assert nanops.nankurt(left_tailed) < 2
 
         alpha, beta = 0.1, 0.3
         right_tailed = self.prng.beta(alpha, beta, size=100)
-        assert nanops.nankurt(right_tailed) > 0
+        assert nanops.nankurt(right_tailed) < 0
 
-    def test_ground_truth(self):
-        kurt = nanops.nankurt(self.samples)
-        tm.assert_almost_equal(kurt, self.actual_kurt)
+    def test_ground_truth(self, samples, actual_kurt):
+        kurt = nanops.nankurt(samples)
+        tm.assert_almost_equal(kurt, actual_kurt)
 
-    def test_axis(self):
-        samples = np.vstack([self.samples, np.nan * np.ones(len(self.samples))])
+    def test_axis(self, samples, actual_kurt):
+        samples = np.vstack([samples, np.nan * np.ones(len(samples))])
         kurt = nanops.nankurt(samples, axis=1)
-        tm.assert_almost_equal(kurt, np.array([self.actual_kurt, np.nan]))
+        tm.assert_almost_equal(kurt, np.array([actual_kurt, np.nan]))
 
-    def test_nans(self):
-        samples = np.hstack([self.samples, np.nan])
+    def test_nans(self, samples):
+        samples = np.hstack([samples, np.nan])
         kurt = nanops.nankurt(samples, skipna=False)
         assert np.isnan(kurt)
 
-    def test_nans_skipna(self):
-        samples = np.hstack([self.samples, np.nan])
+    def test_nans_skipna(self, samples, actual_kurt):
+        samples = np.hstack([samples, np.nan])
         kurt = nanops.nankurt(samples, skipna=True)
-        tm.assert_almost_equal(kurt, self.actual_kurt)
+        tm.assert_almost_equal(kurt, actual_kurt)
 
     @property
     def prng(self):
-        return np.random.RandomState(1234)
+        return np.random.default_rng(2)
 
 
 class TestDatetime64NaNOps:
+    @pytest.fixture(params=["s", "ms", "us", "ns"])
+    def unit(self, request):
+        return request.param
+
     # Enabling mean changes the behavior of DataFrame.mean
     # See https://github.com/pandas-dev/pandas/issues/24752
-    def test_nanmean(self):
-        dti = pd.date_range("2016-01-01", periods=3)
+    def test_nanmean(self, unit):
+        dti = pd.date_range("2016-01-01", periods=3).as_unit(unit)
         expected = dti[1]
 
-        for obj in [dti, DatetimeArray(dti), Series(dti)]:
+        for obj in [dti, dti._data]:
             result = nanops.nanmean(obj)
             assert result == expected
 
         dti2 = dti.insert(1, pd.NaT)
 
-        for obj in [dti2, DatetimeArray(dti2), Series(dti2)]:
+        for obj in [dti2, dti2._data]:
             result = nanops.nanmean(obj)
             assert result == expected
 
-    @pytest.mark.parametrize("dtype", ["M8[ns]", "m8[ns]"])
-    def test_nanmean_skipna_false(self, dtype):
+    @pytest.mark.parametrize("constructor", ["M8", "m8"])
+    def test_nanmean_skipna_false(self, constructor, unit):
+        dtype = f"{constructor}[{unit}]"
         arr = np.arange(12).astype(np.int64).view(dtype).reshape(4, 3)
 
         arr[-1, -1] = "NaT"
 
         result = nanops.nanmean(arr, skipna=False)
-        assert result is pd.NaT
+        assert np.isnat(result)
+        assert result.dtype == dtype
 
         result = nanops.nanmean(arr, axis=0, skipna=False)
         expected = np.array([4, 5, "NaT"], dtype=arr.dtype)
@@ -1033,16 +1143,12 @@ class TestDatetime64NaNOps:
 
 
 def test_use_bottleneck():
-
     if nanops._BOTTLENECK_INSTALLED:
+        with pd.option_context("use_bottleneck", True):
+            assert pd.get_option("use_bottleneck")
 
-        pd.set_option("use_bottleneck", True)
-        assert pd.get_option("use_bottleneck")
-
-        pd.set_option("use_bottleneck", False)
-        assert not pd.get_option("use_bottleneck")
-
-        pd.set_option("use_bottleneck", use_bn)
+        with pd.option_context("use_bottleneck", False):
+            assert not pd.get_option("use_bottleneck")
 
 
 @pytest.mark.parametrize(
@@ -1088,8 +1194,81 @@ def test_numpy_ops(numpy_op, expected):
 )
 def test_nanops_independent_of_mask_param(operation):
     # GH22764
-    s = Series([1, 2, np.nan, 3, np.nan, 4])
-    mask = s.isna()
-    median_expected = operation(s)
-    median_result = operation(s, mask=mask)
+    ser = Series([1, 2, np.nan, 3, np.nan, 4])
+    mask = ser.isna()
+    median_expected = operation(ser._values)
+    median_result = operation(ser._values, mask=mask)
     assert median_expected == median_result
+
+
+@pytest.mark.parametrize("min_count", [-1, 0])
+def test_check_below_min_count_negative_or_zero_min_count(min_count):
+    # GH35227
+    result = nanops.check_below_min_count((21, 37), None, min_count)
+    expected_result = False
+    assert result == expected_result
+
+
+@pytest.mark.parametrize(
+    "mask", [None, np.array([False, False, True]), np.array([True] + 9 * [False])]
+)
+@pytest.mark.parametrize("min_count, expected_result", [(1, False), (101, True)])
+def test_check_below_min_count_positive_min_count(mask, min_count, expected_result):
+    # GH35227
+    shape = (10, 10)
+    result = nanops.check_below_min_count(shape, mask, min_count)
+    assert result == expected_result
+
+
+@td.skip_if_windows
+@td.skip_if_32bit
+@pytest.mark.parametrize("min_count, expected_result", [(1, False), (2812191852, True)])
+def test_check_below_min_count_large_shape(min_count, expected_result):
+    # GH35227 large shape used to show that the issue is fixed
+    shape = (2244367, 1253)
+    result = nanops.check_below_min_count(shape, mask=None, min_count=min_count)
+    assert result == expected_result
+
+
+@pytest.mark.parametrize("func", ["nanmean", "nansum"])
+def test_check_bottleneck_disallow(any_real_numpy_dtype, func):
+    # GH 42878 bottleneck sometimes produces unreliable results for mean and sum
+    assert not nanops._bn_ok_dtype(np.dtype(any_real_numpy_dtype).type, func)
+
+
+@pytest.mark.parametrize("val", [2**55, -(2**55), 20150515061816532])
+def test_nanmean_overflow(disable_bottleneck, val):
+    # GH 10155
+    # In the previous implementation mean can overflow for int dtypes, it
+    # is now consistent with numpy
+
+    ser = Series(val, index=range(500), dtype=np.int64)
+    result = ser.mean()
+    np_result = ser.values.mean()
+    assert result == val
+    assert result == np_result
+    assert result.dtype == np.float64
+
+
+@pytest.mark.parametrize(
+    "dtype",
+    [
+        np.int16,
+        np.int32,
+        np.int64,
+        np.float32,
+        np.float64,
+        getattr(np, "float128", None),
+    ],
+)
+@pytest.mark.parametrize("method", ["mean", "std", "var", "skew", "kurt", "min", "max"])
+def test_returned_dtype(disable_bottleneck, dtype, method):
+    if dtype is None:
+        pytest.skip("np.float128 not available")
+
+    ser = Series(range(10), dtype=dtype)
+    result = getattr(ser, method)()
+    if is_integer_dtype(dtype) and method not in ["min", "max"]:
+        assert result.dtype == np.float64
+    else:
+        assert result.dtype == dtype
