@@ -6,16 +6,18 @@ from datetime import datetime
 from dateutil.relativedelta import relativedelta
 import pytest
 
-from pandas._libs.tslibs.frequencies import INVALID_FREQ_ERR_MSG
-
 from pandas import Timestamp
 import pandas._testing as tm
+from pandas.tests.tseries.offsets.common import (
+    WeekDay,
+    assert_is_on_offset,
+    assert_offset_equal,
+)
 
-from pandas.tseries.frequencies import get_offset
-from pandas.tseries.offsets import FY5253, FY5253Quarter
-
-from .common import assert_is_on_offset, assert_offset_equal
-from .test_offsets import Base, WeekDay
+from pandas.tseries.offsets import (
+    FY5253,
+    FY5253Quarter,
+)
 
 
 def makeFY5253LastOfMonthQuarter(*args, **kwds):
@@ -49,53 +51,13 @@ def test_get_offset_name():
     )
 
 
-def test_get_offset():
-    with pytest.raises(ValueError, match=INVALID_FREQ_ERR_MSG):
-        with tm.assert_produces_warning(FutureWarning):
-            get_offset("gibberish")
-    with pytest.raises(ValueError, match=INVALID_FREQ_ERR_MSG):
-        with tm.assert_produces_warning(FutureWarning):
-            get_offset("QS-JAN-B")
-
-    pairs = [
-        ("RE-N-DEC-MON", makeFY5253NearestEndMonth(weekday=0, startingMonth=12)),
-        ("RE-L-DEC-TUE", makeFY5253LastOfMonth(weekday=1, startingMonth=12)),
-        (
-            "REQ-L-MAR-TUE-4",
-            makeFY5253LastOfMonthQuarter(
-                weekday=1, startingMonth=3, qtr_with_extra_week=4
-            ),
-        ),
-        (
-            "REQ-L-DEC-MON-3",
-            makeFY5253LastOfMonthQuarter(
-                weekday=0, startingMonth=12, qtr_with_extra_week=3
-            ),
-        ),
-        (
-            "REQ-N-DEC-MON-3",
-            makeFY5253NearestEndMonthQuarter(
-                weekday=0, startingMonth=12, qtr_with_extra_week=3
-            ),
-        ),
-    ]
-
-    for name, expected in pairs:
-        with tm.assert_produces_warning(FutureWarning):
-            offset = get_offset(name)
-        assert offset == expected, (
-            f"Expected {repr(name)} to yield {repr(expected)} "
-            f"(actual: {repr(offset)})"
-        )
-
-
-class TestFY5253LastOfMonth(Base):
+class TestFY5253LastOfMonth:
     offset_lom_sat_aug = makeFY5253LastOfMonth(1, startingMonth=8, weekday=WeekDay.SAT)
     offset_lom_sat_sep = makeFY5253LastOfMonth(1, startingMonth=9, weekday=WeekDay.SAT)
 
     on_offset_cases = [
         # From Wikipedia (see:
-        # http://en.wikipedia.org/wiki/4%E2%80%934%E2%80%935_calendar#Last_Saturday_of_the_month_at_fiscal_year_end)
+        # https://en.wikipedia.org/wiki/4%E2%80%934%E2%80%935_calendar#Last_Saturday_of_the_month_at_fiscal_year_end)
         (offset_lom_sat_aug, datetime(2006, 8, 26), True),
         (offset_lom_sat_aug, datetime(2007, 8, 25), True),
         (offset_lom_sat_aug, datetime(2008, 8, 30), True),
@@ -174,7 +136,7 @@ class TestFY5253LastOfMonth(Base):
                 assert current == datum
 
 
-class TestFY5253NearestEndMonth(Base):
+class TestFY5253NearestEndMonth:
     def test_get_year_end(self):
         assert makeFY5253NearestEndMonth(
             startingMonth=8, weekday=WeekDay.SAT
@@ -208,7 +170,7 @@ class TestFY5253NearestEndMonth(Base):
 
     on_offset_cases = [
         #    From Wikipedia (see:
-        #    http://en.wikipedia.org/wiki/4%E2%80%934%E2%80%935_calendar
+        #    https://en.wikipedia.org/wiki/4%E2%80%934%E2%80%935_calendar
         #    #Saturday_nearest_the_end_of_month)
         #    2006-09-02   2006 September 2
         #    2007-09-01   2007 September 1
@@ -332,17 +294,20 @@ class TestFY5253NearestEndMonth(Base):
                 assert current == datum
 
 
-class TestFY5253LastOfMonthQuarter(Base):
+class TestFY5253LastOfMonthQuarter:
     def test_is_anchored(self):
-        assert makeFY5253LastOfMonthQuarter(
-            startingMonth=1, weekday=WeekDay.SAT, qtr_with_extra_week=4
-        ).is_anchored()
-        assert makeFY5253LastOfMonthQuarter(
-            weekday=WeekDay.SAT, startingMonth=3, qtr_with_extra_week=4
-        ).is_anchored()
-        assert not makeFY5253LastOfMonthQuarter(
-            2, startingMonth=1, weekday=WeekDay.SAT, qtr_with_extra_week=4
-        ).is_anchored()
+        msg = "FY5253Quarter.is_anchored is deprecated "
+
+        with tm.assert_produces_warning(FutureWarning, match=msg):
+            assert makeFY5253LastOfMonthQuarter(
+                startingMonth=1, weekday=WeekDay.SAT, qtr_with_extra_week=4
+            ).is_anchored()
+            assert makeFY5253LastOfMonthQuarter(
+                weekday=WeekDay.SAT, startingMonth=3, qtr_with_extra_week=4
+            ).is_anchored()
+            assert not makeFY5253LastOfMonthQuarter(
+                2, startingMonth=1, weekday=WeekDay.SAT, qtr_with_extra_week=4
+            ).is_anchored()
 
     def test_equality(self):
         assert makeFY5253LastOfMonthQuarter(
@@ -548,8 +513,7 @@ class TestFY5253LastOfMonthQuarter(Base):
         assert sat_dec_1.get_weeks(datetime(2010, 12, 25)) == [13, 13, 13, 13]
 
 
-class TestFY5253NearestEndMonthQuarter(Base):
-
+class TestFY5253NearestEndMonthQuarter:
     offset_nem_sat_aug_4 = makeFY5253NearestEndMonthQuarter(
         1, startingMonth=8, weekday=WeekDay.SAT, qtr_with_extra_week=4
     )
@@ -637,18 +601,18 @@ def test_bunched_yearends():
     fy = FY5253(n=1, weekday=5, startingMonth=12, variation="nearest")
     dt = Timestamp("2004-01-01")
     assert fy.rollback(dt) == Timestamp("2002-12-28")
-    assert (-fy).apply(dt) == Timestamp("2002-12-28")
+    assert (-fy)._apply(dt) == Timestamp("2002-12-28")
     assert dt - fy == Timestamp("2002-12-28")
 
     assert fy.rollforward(dt) == Timestamp("2004-01-03")
-    assert fy.apply(dt) == Timestamp("2004-01-03")
+    assert fy._apply(dt) == Timestamp("2004-01-03")
     assert fy + dt == Timestamp("2004-01-03")
     assert dt + fy == Timestamp("2004-01-03")
 
     # Same thing, but starting from a Timestamp in the previous year.
     dt = Timestamp("2003-12-31")
     assert fy.rollback(dt) == Timestamp("2002-12-28")
-    assert (-fy).apply(dt) == Timestamp("2002-12-28")
+    assert (-fy)._apply(dt) == Timestamp("2002-12-28")
     assert dt - fy == Timestamp("2002-12-28")
 
 
