@@ -4,6 +4,7 @@ Quantilization functions and related stuff
 from __future__ import annotations
 
 from typing import (
+    TYPE_CHECKING,
     Any,
     Callable,
     Literal,
@@ -14,24 +15,21 @@ import numpy as np
 from pandas._libs import (
     Timedelta,
     Timestamp,
+    lib,
 )
-from pandas._libs.lib import infer_dtype
-from pandas._typing import IntervalLeftRight
 
 from pandas.core.dtypes.common import (
-    DT64NS_DTYPE,
     ensure_platform_int,
     is_bool_dtype,
-    is_categorical_dtype,
-    is_datetime64_dtype,
-    is_datetime64tz_dtype,
-    is_datetime_or_timedelta_dtype,
-    is_extension_array_dtype,
     is_integer,
     is_list_like,
     is_numeric_dtype,
     is_scalar,
-    is_timedelta64_dtype,
+)
+from pandas.core.dtypes.dtypes import (
+    CategoricalDtype,
+    DatetimeTZDtype,
+    ExtensionDtype,
 )
 from pandas.core.dtypes.generic import ABCSeries
 from pandas.core.dtypes.missing import isna
@@ -40,11 +38,15 @@ from pandas import (
     Categorical,
     Index,
     IntervalIndex,
-    to_datetime,
-    to_timedelta,
 )
 import pandas.core.algorithms as algos
-import pandas.core.nanops as nanops
+from pandas.core.arrays.datetimelike import dtype_to_unit
+
+if TYPE_CHECKING:
+    from pandas._typing import (
+        DtypeObj,
+        IntervalLeftRight,
+    )
 
 
 def cut(
@@ -108,8 +110,6 @@ def cut(
         the resulting categorical will be ordered. If False, the resulting
         categorical will be unordered (labels must be provided).
 
-        .. versionadded:: 1.1.0
-
     Returns
     -------
     out : Categorical, Series, or ndarray
@@ -239,70 +239,33 @@ def cut(
     # NOTE: this binning code is changed a bit from histogram for var(x) == 0
 
     original = x
-    x = _preprocess_for_cut(x)
-    x, dtype = _coerce_to_type(x)
+    x_idx = _preprocess_for_cut(x)
+    x_idx, _ = _coerce_to_type(x_idx)
 
     if not np.iterable(bins):
-        if is_scalar(bins) and bins < 1:
-            raise ValueError("`bins` should be a positive integer.")
-
-        try:  # for array-like
-            sz = x.size
-        except AttributeError:
-            x = np.asarray(x)
-            sz = x.size
-
-        if sz == 0:
-            raise ValueError("Cannot cut empty array")
-
-        rng = (nanops.nanmin(x), nanops.nanmax(x))
-        mn, mx = (mi + 0.0 for mi in rng)
-
-        if np.isinf(mn) or np.isinf(mx):
-            # GH 24314
-            raise ValueError(
-                "cannot specify integer `bins` when input data contains infinity"
-            )
-        elif mn == mx:  # adjust end points before binning
-            mn -= 0.001 * abs(mn) if mn != 0 else 0.001
-            mx += 0.001 * abs(mx) if mx != 0 else 0.001
-            bins = np.linspace(mn, mx, bins + 1, endpoint=True)
-        else:  # adjust end points after binning
-            bins = np.linspace(mn, mx, bins + 1, endpoint=True)
-            adj = (mx - mn) * 0.001  # 0.1% of the range
-            if right:
-                bins[0] -= adj
-            else:
-                bins[-1] += adj
+        bins = _nbins_to_bins(x_idx, bins, right)
 
     elif isinstance(bins, IntervalIndex):
         if bins.is_overlapping:
             raise ValueError("Overlapping IntervalIndex is not accepted.")
 
     else:
-        if is_datetime64tz_dtype(bins):
-            bins = np.asarray(bins, dtype=DT64NS_DTYPE)
-        else:
-            bins = np.asarray(bins)
-        bins = _convert_bin_to_numeric_type(bins, dtype)
-
-        # GH 26045: cast to float64 to avoid an overflow
-        if (np.diff(bins.astype("float64")) < 0).any():
+        bins = Index(bins)
+        if not bins.is_monotonic_increasing:
             raise ValueError("bins must increase monotonically.")
 
     fac, bins = _bins_to_cuts(
-        x,
+        x_idx,
         bins,
         right=right,
         labels=labels,
         precision=precision,
         include_lowest=include_lowest,
-        dtype=dtype,
         duplicates=duplicates,
         ordered=ordered,
     )
 
-    return _postprocess_for_cut(fac, bins, retbins, dtype, original)
+    return _postprocess_for_cut(fac, bins, retbins, original)
 
 
 def qcut(
@@ -367,36 +330,93 @@ def qcut(
     array([0, 0, 1, 2, 3])
     """
     original = x
-    x = _preprocess_for_cut(x)
-    x, dtype = _coerce_to_type(x)
+    x_idx = _preprocess_for_cut(x)
+    x_idx, _ = _coerce_to_type(x_idx)
 
     quantiles = np.linspace(0, 1, q + 1) if is_integer(q) else q
 
-    x_np = np.asarray(x)
-    x_np = x_np[~np.isnan(x_np)]
-    bins = np.quantile(x_np, quantiles)
+    bins = x_idx.to_series().dropna().quantile(quantiles)
 
     fac, bins = _bins_to_cuts(
-        x,
-        bins,
+        x_idx,
+        Index(bins),
         labels=labels,
         precision=precision,
         include_lowest=True,
-        dtype=dtype,
         duplicates=duplicates,
     )
 
-    return _postprocess_for_cut(fac, bins, retbins, dtype, original)
+    return _postprocess_for_cut(fac, bins, retbins, original)
+
+
+def _nbins_to_bins(x_idx: Index, nbins: int, right: bool) -> Index:
+    """
+    If a user passed an integer N for bins, convert this to a sequence of N
+    equal(ish)-sized bins.
+    """
+    if is_scalar(nbins) and nbins < 1:
+        raise ValueError("`bins` should be a positive integer.")
+
+    if x_idx.size == 0:
+        raise ValueError("Cannot cut empty array")
+
+    rng = (x_idx.min(), x_idx.max())
+    mn, mx = rng
+
+    if is_numeric_dtype(x_idx.dtype) and (np.isinf(mn) or np.isinf(mx)):
+        # GH#24314
+        raise ValueError(
+            "cannot specify integer `bins` when input data contains infinity"
+        )
+
+    if mn == mx:  # adjust end points before binning
+        if _is_dt_or_td(x_idx.dtype):
+            # using seconds=1 is pretty arbitrary here
+            # error: Argument 1 to "dtype_to_unit" has incompatible type
+            # "dtype[Any] | ExtensionDtype"; expected "DatetimeTZDtype | dtype[Any]"
+            unit = dtype_to_unit(x_idx.dtype)  # type: ignore[arg-type]
+            td = Timedelta(seconds=1).as_unit(unit)
+            # Use DatetimeArray/TimedeltaArray method instead of linspace
+            # error: Item "ExtensionArray" of "ExtensionArray | ndarray[Any, Any]"
+            # has no attribute "_generate_range"
+            bins = x_idx._values._generate_range(  # type: ignore[union-attr]
+                start=mn - td, end=mx + td, periods=nbins + 1, freq=None, unit=unit
+            )
+        else:
+            mn -= 0.001 * abs(mn) if mn != 0 else 0.001
+            mx += 0.001 * abs(mx) if mx != 0 else 0.001
+
+            bins = np.linspace(mn, mx, nbins + 1, endpoint=True)
+    else:  # adjust end points after binning
+        if _is_dt_or_td(x_idx.dtype):
+            # Use DatetimeArray/TimedeltaArray method instead of linspace
+
+            # error: Argument 1 to "dtype_to_unit" has incompatible type
+            # "dtype[Any] | ExtensionDtype"; expected "DatetimeTZDtype | dtype[Any]"
+            unit = dtype_to_unit(x_idx.dtype)  # type: ignore[arg-type]
+            # error: Item "ExtensionArray" of "ExtensionArray | ndarray[Any, Any]"
+            # has no attribute "_generate_range"
+            bins = x_idx._values._generate_range(  # type: ignore[union-attr]
+                start=mn, end=mx, periods=nbins + 1, freq=None, unit=unit
+            )
+        else:
+            bins = np.linspace(mn, mx, nbins + 1, endpoint=True)
+        adj = (mx - mn) * 0.001  # 0.1% of the range
+        if right:
+            bins[0] -= adj
+        else:
+            bins[-1] += adj
+
+    return Index(bins)
 
 
 def _bins_to_cuts(
-    x,
-    bins: np.ndarray,
+    x_idx: Index,
+    bins: Index,
     right: bool = True,
     labels=None,
     precision: int = 3,
     include_lowest: bool = False,
-    dtype=None,
     duplicates: str = "raise",
     ordered: bool = True,
 ):
@@ -408,10 +428,13 @@ def _bins_to_cuts(
             "invalid value for 'duplicates' parameter, valid options are: raise, drop"
         )
 
+    result: Categorical | np.ndarray
+
     if isinstance(bins, IntervalIndex):
         # we have a fast-path here
-        ids = bins.get_indexer(x)
-        result = Categorical.from_codes(ids, categories=bins, ordered=True)
+        ids = bins.get_indexer(x_idx)
+        cat_dtype = CategoricalDtype(bins, ordered=True)
+        result = Categorical.from_codes(ids, dtype=cat_dtype, validate=False)
         return result, bins
 
     unique_bins = algos.unique(bins)
@@ -421,16 +444,32 @@ def _bins_to_cuts(
                 f"Bin edges must be unique: {repr(bins)}.\n"
                 f"You can drop duplicate edges by setting the 'duplicates' kwarg"
             )
-        else:
-            bins = unique_bins
+        bins = unique_bins
 
     side: Literal["left", "right"] = "left" if right else "right"
-    ids = ensure_platform_int(bins.searchsorted(x, side=side))
+
+    try:
+        ids = bins.searchsorted(x_idx, side=side)
+    except TypeError as err:
+        # e.g. test_datetime_nan_error if bins are DatetimeArray and x_idx
+        #  is integers
+        if x_idx.dtype.kind == "m":
+            raise ValueError("bins must be of timedelta64 dtype") from err
+        elif x_idx.dtype.kind == bins.dtype.kind == "M":
+            raise ValueError(
+                "Cannot use timezone-naive bins with timezone-aware values, "
+                "or vice-versa"
+            ) from err
+        elif x_idx.dtype.kind == "M":
+            raise ValueError("bins must be of datetime64 dtype") from err
+        else:
+            raise
+    ids = ensure_platform_int(ids)
 
     if include_lowest:
-        ids[np.asarray(x) == bins[0]] = 1
+        ids[x_idx == bins[0]] = 1
 
-    na_mask = isna(x) | (ids == len(bins)) | (ids == 0)
+    na_mask = isna(x_idx) | (ids == len(bins)) | (ids == 0)
     has_nas = na_mask.any()
 
     if labels is not False:
@@ -440,9 +479,9 @@ def _bins_to_cuts(
                 "list-like argument"
             )
 
-        elif labels is None:
+        if labels is None:
             labels = _format_labels(
-                bins, precision, right=right, include_lowest=include_lowest, dtype=dtype
+                bins, precision, right=right, include_lowest=include_lowest
             )
         elif ordered and len(set(labels)) != len(labels):
             raise ValueError(
@@ -454,7 +493,8 @@ def _bins_to_cuts(
                 raise ValueError(
                     "Bin labels must be one fewer than the number of bin edges"
                 )
-        if not is_categorical_dtype(labels):
+
+        if not isinstance(getattr(labels, "dtype", None), CategoricalDtype):
             labels = Categorical(
                 labels,
                 categories=labels if len(set(labels)) == len(labels) else None,
@@ -473,22 +513,16 @@ def _bins_to_cuts(
     return result, bins
 
 
-def _coerce_to_type(x):
+def _coerce_to_type(x: Index) -> tuple[Index, DtypeObj | None]:
     """
     if the passed data is of datetime/timedelta, bool or nullable int type,
     this method converts it to numeric so that cut or qcut method can
     handle it
     """
-    dtype = None
+    dtype: DtypeObj | None = None
 
-    if is_datetime64tz_dtype(x.dtype):
+    if _is_dt_or_td(x.dtype):
         dtype = x.dtype
-    elif is_datetime64_dtype(x.dtype):
-        x = to_datetime(x)
-        dtype = np.dtype("datetime64[ns]")
-    elif is_timedelta64_dtype(x.dtype):
-        x = to_timedelta(x)
-        dtype = np.dtype("timedelta64[ns]")
     elif is_bool_dtype(x.dtype):
         # GH 20303
         x = x.astype(np.int64)
@@ -496,84 +530,36 @@ def _coerce_to_type(x):
     # Will properly support in the future.
     # https://github.com/pandas-dev/pandas/pull/31290
     # https://github.com/pandas-dev/pandas/issues/31389
-    elif is_extension_array_dtype(x.dtype) and is_numeric_dtype(x.dtype):
-        x = x.to_numpy(dtype=np.float64, na_value=np.nan)
+    elif isinstance(x.dtype, ExtensionDtype) and is_numeric_dtype(x.dtype):
+        x_arr = x.to_numpy(dtype=np.float64, na_value=np.nan)
+        x = Index(x_arr)
 
-    if dtype is not None:
-        # GH 19768: force NaT to NaN during integer conversion
-        x = np.where(x.notna(), x.view(np.int64), np.nan)
-
-    return x, dtype
+    return Index(x), dtype
 
 
-def _convert_bin_to_numeric_type(bins, dtype):
-    """
-    if the passed bin is of datetime/timedelta type,
-    this method converts it to integer
-
-    Parameters
-    ----------
-    bins : list-like of bins
-    dtype : dtype of data
-
-    Raises
-    ------
-    ValueError if bins are not of a compat dtype to dtype
-    """
-    bins_dtype = infer_dtype(bins, skipna=False)
-    if is_timedelta64_dtype(dtype):
-        if bins_dtype in ["timedelta", "timedelta64"]:
-            bins = to_timedelta(bins).view(np.int64)
-        else:
-            raise ValueError("bins must be of timedelta64 dtype")
-    elif is_datetime64_dtype(dtype) or is_datetime64tz_dtype(dtype):
-        if bins_dtype in ["datetime", "datetime64"]:
-            bins = to_datetime(bins).view(np.int64)
-        else:
-            raise ValueError("bins must be of datetime64 dtype")
-
-    return bins
-
-
-def _convert_bin_to_datelike_type(bins, dtype):
-    """
-    Convert bins to a DatetimeIndex or TimedeltaIndex if the original dtype is
-    datelike
-
-    Parameters
-    ----------
-    bins : list-like of bins
-    dtype : dtype of data
-
-    Returns
-    -------
-    bins : Array-like of bins, DatetimeIndex or TimedeltaIndex if dtype is
-           datelike
-    """
-    if is_datetime64tz_dtype(dtype):
-        bins = to_datetime(bins.astype(np.int64), utc=True).tz_convert(dtype.tz)
-    elif is_datetime_or_timedelta_dtype(dtype):
-        bins = Index(bins.astype(np.int64), dtype=dtype)
-    return bins
+def _is_dt_or_td(dtype: DtypeObj) -> bool:
+    # Note: the dtype here comes from an Index.dtype, so we know that that any
+    #  dt64/td64 dtype is of a supported unit.
+    return isinstance(dtype, DatetimeTZDtype) or lib.is_np_dtype(dtype, "mM")
 
 
 def _format_labels(
-    bins, precision: int, right: bool = True, include_lowest: bool = False, dtype=None
+    bins: Index,
+    precision: int,
+    right: bool = True,
+    include_lowest: bool = False,
 ):
     """based on the dtype, return our labels"""
     closed: IntervalLeftRight = "right" if right else "left"
 
     formatter: Callable[[Any], Timestamp] | Callable[[Any], Timedelta]
 
-    if is_datetime64tz_dtype(dtype):
-        formatter = lambda x: Timestamp(x, tz=dtype.tz)
-        adjust = lambda x: x - Timedelta("1ns")
-    elif is_datetime64_dtype(dtype):
-        formatter = Timestamp
-        adjust = lambda x: x - Timedelta("1ns")
-    elif is_timedelta64_dtype(dtype):
-        formatter = Timedelta
-        adjust = lambda x: x - Timedelta("1ns")
+    if _is_dt_or_td(bins.dtype):
+        # error: Argument 1 to "dtype_to_unit" has incompatible type
+        # "dtype[Any] | ExtensionDtype"; expected "DatetimeTZDtype | dtype[Any]"
+        unit = dtype_to_unit(bins.dtype)  # type: ignore[arg-type]
+        formatter = lambda x: x
+        adjust = lambda x: x - Timedelta(1, unit=unit).as_unit(unit)
     else:
         precision = _infer_precision(precision, bins)
         formatter = lambda x: _round_frac(x, precision)
@@ -584,10 +570,14 @@ def _format_labels(
         # adjust lhs of first interval by precision to account for being right closed
         breaks[0] = adjust(breaks[0])
 
+    if _is_dt_or_td(bins.dtype):
+        # error: "Index" has no attribute "as_unit"
+        breaks = type(bins)(breaks).as_unit(unit)  # type: ignore[attr-defined]
+
     return IntervalIndex.from_breaks(breaks, closed=closed)
 
 
-def _preprocess_for_cut(x):
+def _preprocess_for_cut(x) -> Index:
     """
     handles preprocessing for cut where we convert passed
     input to array, strip the index information and store it
@@ -601,10 +591,10 @@ def _preprocess_for_cut(x):
     if x.ndim != 1:
         raise ValueError("Input array must be 1 dimensional")
 
-    return x
+    return Index(x)
 
 
-def _postprocess_for_cut(fac, bins, retbins: bool, dtype, original):
+def _postprocess_for_cut(fac, bins, retbins: bool, original):
     """
     handles post processing for the cut method where
     we combine the index information if the originally passed
@@ -616,7 +606,8 @@ def _postprocess_for_cut(fac, bins, retbins: bool, dtype, original):
     if not retbins:
         return fac
 
-    bins = _convert_bin_to_datelike_type(bins, dtype)
+    if isinstance(bins, Index) and is_numeric_dtype(bins.dtype):
+        bins = bins._values
 
     return fac, bins
 
@@ -636,12 +627,12 @@ def _round_frac(x, precision: int):
         return np.around(x, digits)
 
 
-def _infer_precision(base_precision: int, bins) -> int:
+def _infer_precision(base_precision: int, bins: Index) -> int:
     """
     Infer an appropriate precision for _round_frac
     """
     for precision in range(base_precision, 20):
-        levels = [_round_frac(b, precision) for b in bins]
+        levels = np.asarray([_round_frac(b, precision) for b in bins])
         if algos.unique(levels).size == bins.size:
             return precision
     return base_precision  # default
