@@ -4,16 +4,18 @@ import io
 import os
 from pathlib import Path
 
-import dateutil.parser
 import numpy as np
 import pytest
 
+from pandas.compat import IS64
 from pandas.errors import EmptyDataError
 import pandas.util._test_decorators as td
 
 import pandas as pd
 import pandas._testing as tm
 
+from pandas.io.sas.sas7bdat import SAS7BDATReader
+
 
 @pytest.fixture
 def dirpath(datapath):
@@ -27,9 +29,9 @@ def data_test_ix(request, dirpath):
     df = pd.read_csv(fname)
     epoch = datetime(1960, 1, 1)
     t1 = pd.to_timedelta(df["Column4"], unit="d")
-    df["Column4"] = epoch + t1
+    df["Column4"] = (epoch + t1).astype("M8[s]")
     t2 = pd.to_timedelta(df["Column12"], unit="d")
-    df["Column12"] = epoch + t2
+    df["Column12"] = (epoch + t2).astype("M8[s]")
     for k in range(df.shape[1]):
         col = df.iloc[:, k]
         if col.dtype == np.int64:
@@ -38,19 +40,18 @@ def data_test_ix(request, dirpath):
 
 
 # https://github.com/cython/cython/issues/1720
-@pytest.mark.filterwarnings("ignore:can't resolve package:ImportWarning")
 class TestSAS7BDAT:
     @pytest.mark.slow
     def test_from_file(self, dirpath, data_test_ix):
-        df0, test_ix = data_test_ix
+        expected, test_ix = data_test_ix
         for k in test_ix:
             fname = os.path.join(dirpath, f"test{k}.sas7bdat")
             df = pd.read_sas(fname, encoding="utf-8")
-            tm.assert_frame_equal(df, df0)
+            tm.assert_frame_equal(df, expected)
 
     @pytest.mark.slow
     def test_from_buffer(self, dirpath, data_test_ix):
-        df0, test_ix = data_test_ix
+        expected, test_ix = data_test_ix
         for k in test_ix:
             fname = os.path.join(dirpath, f"test{k}.sas7bdat")
             with open(fname, "rb") as f:
@@ -60,37 +61,37 @@ class TestSAS7BDAT:
                 buf, format="sas7bdat", iterator=True, encoding="utf-8"
             ) as rdr:
                 df = rdr.read()
-            tm.assert_frame_equal(df, df0, check_exact=False)
+            tm.assert_frame_equal(df, expected)
 
     @pytest.mark.slow
     def test_from_iterator(self, dirpath, data_test_ix):
-        df0, test_ix = data_test_ix
+        expected, test_ix = data_test_ix
         for k in test_ix:
             fname = os.path.join(dirpath, f"test{k}.sas7bdat")
             with pd.read_sas(fname, iterator=True, encoding="utf-8") as rdr:
                 df = rdr.read(2)
-                tm.assert_frame_equal(df, df0.iloc[0:2, :])
+                tm.assert_frame_equal(df, expected.iloc[0:2, :])
                 df = rdr.read(3)
-                tm.assert_frame_equal(df, df0.iloc[2:5, :])
+                tm.assert_frame_equal(df, expected.iloc[2:5, :])
 
     @pytest.mark.slow
     def test_path_pathlib(self, dirpath, data_test_ix):
-        df0, test_ix = data_test_ix
+        expected, test_ix = data_test_ix
         for k in test_ix:
             fname = Path(os.path.join(dirpath, f"test{k}.sas7bdat"))
             df = pd.read_sas(fname, encoding="utf-8")
-            tm.assert_frame_equal(df, df0)
+            tm.assert_frame_equal(df, expected)
 
     @td.skip_if_no("py.path")
     @pytest.mark.slow
     def test_path_localpath(self, dirpath, data_test_ix):
         from py.path import local as LocalPath
 
-        df0, test_ix = data_test_ix
+        expected, test_ix = data_test_ix
         for k in test_ix:
             fname = LocalPath(os.path.join(dirpath, f"test{k}.sas7bdat"))
             df = pd.read_sas(fname, encoding="utf-8")
-            tm.assert_frame_equal(df, df0)
+            tm.assert_frame_equal(df, expected)
 
     @pytest.mark.slow
     @pytest.mark.parametrize("chunksize", (3, 5, 10, 11))
@@ -128,14 +129,27 @@ def test_encoding_options(datapath):
             pass
     tm.assert_frame_equal(df1, df2)
 
-    from pandas.io.sas.sas7bdat import SAS7BDATReader
-
     with contextlib.closing(SAS7BDATReader(fname, convert_header_text=False)) as rdr:
         df3 = rdr.read()
     for x, y in zip(df1.columns, df3.columns):
         assert x == y.decode()
 
 
+def test_encoding_infer(datapath):
+    fname = datapath("io", "sas", "data", "test1.sas7bdat")
+
+    with pd.read_sas(fname, encoding="infer", iterator=True) as df1_reader:
+        # check: is encoding inferred correctly from file
+        assert df1_reader.inferred_encoding == "cp1252"
+        df1 = df1_reader.read()
+
+    with pd.read_sas(fname, encoding="cp1252", iterator=True) as df2_reader:
+        df2 = df2_reader.read()
+
+    # check: reader reads correct information
+    tm.assert_frame_equal(df1, df2)
+
+
 def test_productsales(datapath):
     fname = datapath("io", "sas", "data", "productsales.sas7bdat")
     df = pd.read_sas(fname, encoding="utf-8")
@@ -143,6 +157,8 @@ def test_productsales(datapath):
     df0 = pd.read_csv(fname, parse_dates=["MONTH"])
     vn = ["ACTUAL", "PREDICT", "QUARTER", "YEAR"]
     df0[vn] = df0[vn].astype(np.float64)
+
+    df0["MONTH"] = df0["MONTH"].astype("M8[s]")
     tm.assert_frame_equal(df, df0)
 
 
@@ -161,7 +177,7 @@ def test_airline(datapath):
     fname = datapath("io", "sas", "data", "airline.csv")
     df0 = pd.read_csv(fname)
     df0 = df0.astype(np.float64)
-    tm.assert_frame_equal(df, df0, check_exact=False)
+    tm.assert_frame_equal(df, df0)
 
 
 def test_date_time(datapath):
@@ -173,7 +189,23 @@ def test_date_time(datapath):
         fname, parse_dates=["Date1", "Date2", "DateTime", "DateTimeHi", "Taiw"]
     )
     # GH 19732: Timestamps imported from sas will incur floating point errors
+    # See GH#56014 for discussion of the correct "expected" results
+    #  We are really just testing that we are "close". This only seems to be
+    #  an issue near the implementation bounds.
+
     df[df.columns[3]] = df.iloc[:, 3].dt.round("us")
+    df0["Date1"] = df0["Date1"].astype("M8[s]")
+    df0["Date2"] = df0["Date2"].astype("M8[s]")
+    df0["DateTime"] = df0["DateTime"].astype("M8[ms]")
+    df0["Taiw"] = df0["Taiw"].astype("M8[s]")
+
+    res = df0["DateTimeHi"].astype("M8[us]").dt.round("ms")
+    df0["DateTimeHi"] = res.astype("M8[ms]")
+
+    if not IS64:
+        # No good reason for this, just what we get on the CI
+        df0.loc[0, "DateTimeHi"] += np.timedelta64(1, "ms")
+        df0.loc[[2, 3], "DateTimeHi"] -= np.timedelta64(1, "ms")
     tm.assert_frame_equal(df, df0)
 
 
@@ -233,48 +265,42 @@ def test_corrupt_read(datapath):
         pd.read_sas(fname)
 
 
-def round_datetime_to_ms(ts):
-    if isinstance(ts, datetime):
-        return ts.replace(microsecond=int(round(ts.microsecond, -3) / 1000) * 1000)
-    elif isinstance(ts, str):
-        _ts = dateutil.parser.parse(timestr=ts)
-        return _ts.replace(microsecond=int(round(_ts.microsecond, -3) / 1000) * 1000)
-    else:
-        return ts
-
-
 def test_max_sas_date(datapath):
     # GH 20927
     # NB. max datetime in SAS dataset is 31DEC9999:23:59:59.999
     #    but this is read as 29DEC9999:23:59:59.998993 by a buggy
     #    sas7bdat module
+    # See also GH#56014 for discussion of the correct "expected" results.
     fname = datapath("io", "sas", "data", "max_sas_date.sas7bdat")
     df = pd.read_sas(fname, encoding="iso-8859-1")
 
-    # SAS likes to left pad strings with spaces - lstrip before comparing
-    df = df.applymap(lambda x: x.lstrip() if isinstance(x, str) else x)
-    # GH 19732: Timestamps imported from sas will incur floating point errors
-    try:
-        df["dt_as_dt"] = df["dt_as_dt"].dt.round("us")
-    except pd._libs.tslibs.np_datetime.OutOfBoundsDatetime:
-        df = df.applymap(round_datetime_to_ms)
-    except AttributeError:
-        df["dt_as_dt"] = df["dt_as_dt"].apply(round_datetime_to_ms)
-    # if there are any date/times > pandas.Timestamp.max then ALL in that chunk
-    # are returned as datetime.datetime
     expected = pd.DataFrame(
         {
             "text": ["max", "normal"],
             "dt_as_float": [253717747199.999, 1880323199.999],
-            "dt_as_dt": [
-                datetime(9999, 12, 29, 23, 59, 59, 999000),
-                datetime(2019, 8, 1, 23, 59, 59, 999000),
-            ],
+            "dt_as_dt": np.array(
+                [
+                    datetime(9999, 12, 29, 23, 59, 59, 999000),
+                    datetime(2019, 8, 1, 23, 59, 59, 999000),
+                ],
+                dtype="M8[ms]",
+            ),
             "date_as_float": [2936547.0, 21762.0],
-            "date_as_date": [datetime(9999, 12, 29), datetime(2019, 8, 1)],
+            "date_as_date": np.array(
+                [
+                    datetime(9999, 12, 29),
+                    datetime(2019, 8, 1),
+                ],
+                dtype="M8[s]",
+            ),
         },
         columns=["text", "dt_as_float", "dt_as_dt", "date_as_float", "date_as_date"],
     )
+
+    if not IS64:
+        # No good reason for this, just what we get on the CI
+        expected.loc[:, "dt_as_dt"] -= np.timedelta64(1, "ms")
+
     tm.assert_frame_equal(df, expected)
 
 
@@ -287,15 +313,7 @@ def test_max_sas_date_iterator(datapath):
     fname = datapath("io", "sas", "data", "max_sas_date.sas7bdat")
     results = []
     for df in pd.read_sas(fname, encoding="iso-8859-1", chunksize=1):
-        # SAS likes to left pad strings with spaces - lstrip before comparing
-        df = df.applymap(lambda x: x.lstrip() if isinstance(x, str) else x)
         # GH 19732: Timestamps imported from sas will incur floating point errors
-        try:
-            df["dt_as_dt"] = df["dt_as_dt"].dt.round("us")
-        except pd._libs.tslibs.np_datetime.OutOfBoundsDatetime:
-            df = df.applymap(round_datetime_to_ms)
-        except AttributeError:
-            df["dt_as_dt"] = df["dt_as_dt"].apply(round_datetime_to_ms)
         df.reset_index(inplace=True, drop=True)
         results.append(df)
     expected = [
@@ -303,9 +321,11 @@ def test_max_sas_date_iterator(datapath):
             {
                 "text": ["max"],
                 "dt_as_float": [253717747199.999],
-                "dt_as_dt": [datetime(9999, 12, 29, 23, 59, 59, 999000)],
+                "dt_as_dt": np.array(
+                    [datetime(9999, 12, 29, 23, 59, 59, 999000)], dtype="M8[ms]"
+                ),
                 "date_as_float": [2936547.0],
-                "date_as_date": [datetime(9999, 12, 29)],
+                "date_as_date": np.array([datetime(9999, 12, 29)], dtype="M8[s]"),
             },
             columns=col_order,
         ),
@@ -313,15 +333,20 @@ def test_max_sas_date_iterator(datapath):
             {
                 "text": ["normal"],
                 "dt_as_float": [1880323199.999],
-                "dt_as_dt": [np.datetime64("2019-08-01 23:59:59.999")],
+                "dt_as_dt": np.array(["2019-08-01 23:59:59.999"], dtype="M8[ms]"),
                 "date_as_float": [21762.0],
-                "date_as_date": [np.datetime64("2019-08-01")],
+                "date_as_date": np.array(["2019-08-01"], dtype="M8[s]"),
             },
             columns=col_order,
         ),
     ]
-    for result, expected in zip(results, expected):
-        tm.assert_frame_equal(result, expected)
+    if not IS64:
+        # No good reason for this, just what we get on the CI
+        expected[0].loc[0, "dt_as_dt"] -= np.timedelta64(1, "ms")
+        expected[1].loc[0, "dt_as_dt"] -= np.timedelta64(1, "ms")
+
+    tm.assert_frame_equal(results[0], expected[0])
+    tm.assert_frame_equal(results[1], expected[1])
 
 
 def test_null_date(datapath):
@@ -330,16 +355,25 @@ def test_null_date(datapath):
 
     expected = pd.DataFrame(
         {
-            "datecol": [
-                datetime(9999, 12, 29),
-                pd.NaT,
-            ],
-            "datetimecol": [
-                datetime(9999, 12, 29, 23, 59, 59, 998993),
-                pd.NaT,
-            ],
+            "datecol": np.array(
+                [
+                    datetime(9999, 12, 29),
+                    np.datetime64("NaT"),
+                ],
+                dtype="M8[s]",
+            ),
+            "datetimecol": np.array(
+                [
+                    datetime(9999, 12, 29, 23, 59, 59, 999000),
+                    np.datetime64("NaT"),
+                ],
+                dtype="M8[ms]",
+            ),
         },
     )
+    if not IS64:
+        # No good reason for this, just what we get on the CI
+        expected.loc[0, "datetimecol"] -= np.timedelta64(1, "ms")
     tm.assert_frame_equal(df, expected)
 
 
@@ -350,37 +384,23 @@ def test_meta2_page(datapath):
     assert len(df) == 1000
 
 
-@pytest.mark.parametrize("test_file", ["test2.sas7bdat", "test3.sas7bdat"])
-def test_exception_propagation_rdc_rle_decompress(datapath, monkeypatch, test_file):
-    """Errors in RLE/RDC decompression should propagate the same error."""
-    orig_np_zeros = np.zeros
-
-    def _patched_zeros(size, dtype):
-        if isinstance(size, int):
-            # np.zeros() call in {rdc,rle}_decompress
-            raise Exception("Test exception")
-        else:
-            # Other calls to np.zeros
-            return orig_np_zeros(size, dtype)
-
-    monkeypatch.setattr(np, "zeros", _patched_zeros)
-
-    with pytest.raises(Exception, match="^Test exception$"):
-        pd.read_sas(datapath("io", "sas", "data", test_file))
-
-
-def test_exception_propagation_rle_decompress(tmp_path, datapath):
-    """Illegal control byte in RLE decompressor should raise the correct ValueError."""
-    with open(datapath("io", "sas", "data", "test2.sas7bdat"), "rb") as f:
-        data = bytearray(f.read())
-    invalid_control_byte = 0x10
-    page_offset = 0x10000
-    control_byte_pos = 55229
-    data[page_offset + control_byte_pos] = invalid_control_byte
-    tmp_file = tmp_path / "test2.sas7bdat"
-    tmp_file.write_bytes(data)
-    with pytest.raises(ValueError, match="unknown control byte"):
-        pd.read_sas(tmp_file)
+@pytest.mark.parametrize(
+    "test_file, override_offset, override_value, expected_msg",
+    [
+        ("test2.sas7bdat", 0x10000 + 55229, 0x80 | 0x0F, "Out of bounds"),
+        ("test2.sas7bdat", 0x10000 + 55229, 0x10, "unknown control byte"),
+        ("test3.sas7bdat", 118170, 184, "Out of bounds"),
+    ],
+)
+def test_rle_rdc_exceptions(
+    datapath, test_file, override_offset, override_value, expected_msg
+):
+    """Errors in RLE/RDC decompression should propagate."""
+    with open(datapath("io", "sas", "data", test_file), "rb") as fd:
+        data = bytearray(fd.read())
+    data[override_offset] = override_value
+    with pytest.raises(Exception, match=expected_msg):
+        pd.read_sas(io.BytesIO(data), format="sas7bdat")
 
 
 def test_0x40_control_byte(datapath):
