@@ -1,186 +1,131 @@
+import re
+
 import numpy as np
-from numpy.random import randn
 import pytest
 
-from pandas._libs import join as libjoin
+import pandas.util._test_decorators as td
 
 import pandas as pd
-from pandas import DataFrame, Index, MultiIndex, Series, concat, merge
+from pandas import (
+    Categorical,
+    DataFrame,
+    Index,
+    MultiIndex,
+    Series,
+    Timestamp,
+    bdate_range,
+    concat,
+    merge,
+    option_context,
+)
 import pandas._testing as tm
-from pandas.tests.reshape.merge.test_merge import NGROUPS, N, get_test_data
 
-a_ = np.array
+
+def get_test_data(ngroups=8, n=50):
+    unique_groups = list(range(ngroups))
+    arr = np.asarray(np.tile(unique_groups, n // ngroups))
+
+    if len(arr) < n:
+        arr = np.asarray(list(arr) + unique_groups[: n - len(arr)])
+
+    np.random.default_rng(2).shuffle(arr)
+    return arr
 
 
 class TestJoin:
-    def setup_method(self, method):
-        # aggregate multiple columns
-        self.df = DataFrame(
+    # aggregate multiple columns
+    @pytest.fixture
+    def df(self):
+        df = DataFrame(
             {
                 "key1": get_test_data(),
                 "key2": get_test_data(),
-                "data1": np.random.randn(N),
-                "data2": np.random.randn(N),
+                "data1": np.random.default_rng(2).standard_normal(50),
+                "data2": np.random.default_rng(2).standard_normal(50),
             }
         )
 
         # exclude a couple keys for fun
-        self.df = self.df[self.df["key2"] > 1]
+        df = df[df["key2"] > 1]
+        return df
 
-        self.df2 = DataFrame(
+    @pytest.fixture
+    def df2(self):
+        return DataFrame(
             {
-                "key1": get_test_data(n=N // 5),
-                "key2": get_test_data(ngroups=NGROUPS // 2, n=N // 5),
-                "value": np.random.randn(N // 5),
+                "key1": get_test_data(n=10),
+                "key2": get_test_data(ngroups=4, n=10),
+                "value": np.random.default_rng(2).standard_normal(10),
             }
         )
 
-        index, data = tm.getMixedTypeDict()
-        self.target = DataFrame(data, index=index)
+    @pytest.fixture
+    def target_source(self):
+        data = {
+            "A": [0.0, 1.0, 2.0, 3.0, 4.0],
+            "B": [0.0, 1.0, 0.0, 1.0, 0.0],
+            "C": ["foo1", "foo2", "foo3", "foo4", "foo5"],
+            "D": bdate_range("1/1/2009", periods=5),
+        }
+        target = DataFrame(data, index=Index(["a", "b", "c", "d", "e"], dtype=object))
 
         # Join on string value
-        self.source = DataFrame(
+
+        source = DataFrame(
             {"MergedA": data["A"], "MergedD": data["D"]}, index=data["C"]
         )
+        return target, source
 
-    def test_cython_left_outer_join(self):
-        left = a_([0, 1, 2, 1, 2, 0, 0, 1, 2, 3, 3], dtype=np.int64)
-        right = a_([1, 1, 0, 4, 2, 2, 1], dtype=np.int64)
-        max_group = 5
+    def test_left_outer_join(self, df, df2):
+        joined_key2 = merge(df, df2, on="key2")
+        _check_join(df, df2, joined_key2, ["key2"], how="left")
 
-        ls, rs = libjoin.left_outer_join(left, right, max_group)
+        joined_both = merge(df, df2)
+        _check_join(df, df2, joined_both, ["key1", "key2"], how="left")
 
-        exp_ls = left.argsort(kind="mergesort")
-        exp_rs = right.argsort(kind="mergesort")
+    def test_right_outer_join(self, df, df2):
+        joined_key2 = merge(df, df2, on="key2", how="right")
+        _check_join(df, df2, joined_key2, ["key2"], how="right")
 
-        exp_li = a_([0, 1, 2, 3, 3, 3, 4, 4, 4, 5, 5, 5, 6, 6, 7, 7, 8, 8, 9, 10])
-        exp_ri = a_([0, 0, 0, 1, 2, 3, 1, 2, 3, 1, 2, 3, 4, 5, 4, 5, 4, 5, -1, -1])
+        joined_both = merge(df, df2, how="right")
+        _check_join(df, df2, joined_both, ["key1", "key2"], how="right")
 
-        exp_ls = exp_ls.take(exp_li)
-        exp_ls[exp_li == -1] = -1
+    def test_full_outer_join(self, df, df2):
+        joined_key2 = merge(df, df2, on="key2", how="outer")
+        _check_join(df, df2, joined_key2, ["key2"], how="outer")
 
-        exp_rs = exp_rs.take(exp_ri)
-        exp_rs[exp_ri == -1] = -1
+        joined_both = merge(df, df2, how="outer")
+        _check_join(df, df2, joined_both, ["key1", "key2"], how="outer")
 
-        tm.assert_numpy_array_equal(ls, exp_ls, check_dtype=False)
-        tm.assert_numpy_array_equal(rs, exp_rs, check_dtype=False)
+    def test_inner_join(self, df, df2):
+        joined_key2 = merge(df, df2, on="key2", how="inner")
+        _check_join(df, df2, joined_key2, ["key2"], how="inner")
 
-    def test_cython_right_outer_join(self):
-        left = a_([0, 1, 2, 1, 2, 0, 0, 1, 2, 3, 3], dtype=np.int64)
-        right = a_([1, 1, 0, 4, 2, 2, 1], dtype=np.int64)
-        max_group = 5
+        joined_both = merge(df, df2, how="inner")
+        _check_join(df, df2, joined_both, ["key1", "key2"], how="inner")
 
-        rs, ls = libjoin.left_outer_join(right, left, max_group)
-
-        exp_ls = left.argsort(kind="mergesort")
-        exp_rs = right.argsort(kind="mergesort")
-
-        #            0        1        1        1
-        exp_li = a_(
-            [
-                0,
-                1,
-                2,
-                3,
-                4,
-                5,
-                3,
-                4,
-                5,
-                3,
-                4,
-                5,
-                #            2        2        4
-                6,
-                7,
-                8,
-                6,
-                7,
-                8,
-                -1,
-            ]
-        )
-        exp_ri = a_([0, 0, 0, 1, 1, 1, 2, 2, 2, 3, 3, 3, 4, 4, 4, 5, 5, 5, 6])
-
-        exp_ls = exp_ls.take(exp_li)
-        exp_ls[exp_li == -1] = -1
-
-        exp_rs = exp_rs.take(exp_ri)
-        exp_rs[exp_ri == -1] = -1
-
-        tm.assert_numpy_array_equal(ls, exp_ls, check_dtype=False)
-        tm.assert_numpy_array_equal(rs, exp_rs, check_dtype=False)
-
-    def test_cython_inner_join(self):
-        left = a_([0, 1, 2, 1, 2, 0, 0, 1, 2, 3, 3], dtype=np.int64)
-        right = a_([1, 1, 0, 4, 2, 2, 1, 4], dtype=np.int64)
-        max_group = 5
-
-        ls, rs = libjoin.inner_join(left, right, max_group)
-
-        exp_ls = left.argsort(kind="mergesort")
-        exp_rs = right.argsort(kind="mergesort")
-
-        exp_li = a_([0, 1, 2, 3, 3, 3, 4, 4, 4, 5, 5, 5, 6, 6, 7, 7, 8, 8])
-        exp_ri = a_([0, 0, 0, 1, 2, 3, 1, 2, 3, 1, 2, 3, 4, 5, 4, 5, 4, 5])
-
-        exp_ls = exp_ls.take(exp_li)
-        exp_ls[exp_li == -1] = -1
-
-        exp_rs = exp_rs.take(exp_ri)
-        exp_rs[exp_ri == -1] = -1
-
-        tm.assert_numpy_array_equal(ls, exp_ls, check_dtype=False)
-        tm.assert_numpy_array_equal(rs, exp_rs, check_dtype=False)
-
-    def test_left_outer_join(self):
-        joined_key2 = merge(self.df, self.df2, on="key2")
-        _check_join(self.df, self.df2, joined_key2, ["key2"], how="left")
-
-        joined_both = merge(self.df, self.df2)
-        _check_join(self.df, self.df2, joined_both, ["key1", "key2"], how="left")
-
-    def test_right_outer_join(self):
-        joined_key2 = merge(self.df, self.df2, on="key2", how="right")
-        _check_join(self.df, self.df2, joined_key2, ["key2"], how="right")
-
-        joined_both = merge(self.df, self.df2, how="right")
-        _check_join(self.df, self.df2, joined_both, ["key1", "key2"], how="right")
-
-    def test_full_outer_join(self):
-        joined_key2 = merge(self.df, self.df2, on="key2", how="outer")
-        _check_join(self.df, self.df2, joined_key2, ["key2"], how="outer")
-
-        joined_both = merge(self.df, self.df2, how="outer")
-        _check_join(self.df, self.df2, joined_both, ["key1", "key2"], how="outer")
-
-    def test_inner_join(self):
-        joined_key2 = merge(self.df, self.df2, on="key2", how="inner")
-        _check_join(self.df, self.df2, joined_key2, ["key2"], how="inner")
-
-        joined_both = merge(self.df, self.df2, how="inner")
-        _check_join(self.df, self.df2, joined_both, ["key1", "key2"], how="inner")
-
-    def test_handle_overlap(self):
-        joined = merge(self.df, self.df2, on="key2", suffixes=[".foo", ".bar"])
+    def test_handle_overlap(self, df, df2):
+        joined = merge(df, df2, on="key2", suffixes=(".foo", ".bar"))
 
         assert "key1.foo" in joined
         assert "key1.bar" in joined
 
-    def test_handle_overlap_arbitrary_key(self):
+    def test_handle_overlap_arbitrary_key(self, df, df2):
         joined = merge(
-            self.df,
-            self.df2,
+            df,
+            df2,
             left_on="key2",
             right_on="key1",
-            suffixes=[".foo", ".bar"],
+            suffixes=(".foo", ".bar"),
         )
         assert "key1.foo" in joined
         assert "key2.bar" in joined
 
-    def test_join_on(self):
-        target = self.target
-        source = self.source
+    @pytest.mark.parametrize(
+        "infer_string", [False, pytest.param(True, marks=td.skip_if_no("pyarrow"))]
+    )
+    def test_join_on(self, target_source, infer_string):
+        target, source = target_source
 
         merged = target.join(source, on="C")
         tm.assert_series_equal(merged["MergedA"], target["A"], check_names=False)
@@ -210,21 +155,26 @@ class TestJoin:
 
         # overlap
         source_copy = source.copy()
-        source_copy["A"] = 0
         msg = (
-            "You are trying to merge on float64 and object columns. If"
-            " you wish to proceed you should use pd.concat"
+            "You are trying to merge on float64 and object|string columns for key "
+            "'A'. If you wish to proceed you should use pd.concat"
         )
         with pytest.raises(ValueError, match=msg):
             target.join(source_copy, on="A")
 
     def test_join_on_fails_with_different_right_index(self):
         df = DataFrame(
-            {"a": np.random.choice(["m", "f"], size=3), "b": np.random.randn(3)}
+            {
+                "a": np.random.default_rng(2).choice(["m", "f"], size=3),
+                "b": np.random.default_rng(2).standard_normal(3),
+            }
         )
         df2 = DataFrame(
-            {"a": np.random.choice(["m", "f"], size=10), "b": np.random.randn(10)},
-            index=tm.makeCustomIndex(10, 2),
+            {
+                "a": np.random.default_rng(2).choice(["m", "f"], size=10),
+                "b": np.random.default_rng(2).standard_normal(10),
+            },
+            index=MultiIndex.from_product([range(5), ["A", "B"]]),
         )
         msg = r'len\(left_on\) must equal the number of levels in the index of "right"'
         with pytest.raises(ValueError, match=msg):
@@ -232,11 +182,17 @@ class TestJoin:
 
     def test_join_on_fails_with_different_left_index(self):
         df = DataFrame(
-            {"a": np.random.choice(["m", "f"], size=3), "b": np.random.randn(3)},
-            index=tm.makeCustomIndex(3, 2),
+            {
+                "a": np.random.default_rng(2).choice(["m", "f"], size=3),
+                "b": np.random.default_rng(2).standard_normal(3),
+            },
+            index=MultiIndex.from_arrays([range(3), list("abc")]),
         )
         df2 = DataFrame(
-            {"a": np.random.choice(["m", "f"], size=10), "b": np.random.randn(10)}
+            {
+                "a": np.random.default_rng(2).choice(["m", "f"], size=10),
+                "b": np.random.default_rng(2).standard_normal(10),
+            }
         )
         msg = r'len\(right_on\) must equal the number of levels in the index of "left"'
         with pytest.raises(ValueError, match=msg):
@@ -244,11 +200,17 @@ class TestJoin:
 
     def test_join_on_fails_with_different_column_counts(self):
         df = DataFrame(
-            {"a": np.random.choice(["m", "f"], size=3), "b": np.random.randn(3)}
+            {
+                "a": np.random.default_rng(2).choice(["m", "f"], size=3),
+                "b": np.random.default_rng(2).standard_normal(3),
+            }
         )
         df2 = DataFrame(
-            {"a": np.random.choice(["m", "f"], size=10), "b": np.random.randn(10)},
-            index=tm.makeCustomIndex(10, 2),
+            {
+                "a": np.random.default_rng(2).choice(["m", "f"], size=10),
+                "b": np.random.default_rng(2).standard_normal(10),
+            },
+            index=MultiIndex.from_product([range(5), ["A", "B"]]),
         )
         msg = r"len\(right_on\) must equal len\(left_on\)"
         with pytest.raises(ValueError, match=msg):
@@ -262,30 +224,34 @@ class TestJoin:
         # Edited test to remove the Series object from test parameters
 
         df = DataFrame({"a": [1, 1]})
-        msg = "Can only merge Series or DataFrame objects, a {} was passed".format(
-            str(type(wrong_type))
+        msg = (
+            "Can only merge Series or DataFrame objects, "
+            f"a {type(wrong_type)} was passed"
         )
         with pytest.raises(TypeError, match=msg):
             merge(wrong_type, df, left_on="a", right_on="a")
         with pytest.raises(TypeError, match=msg):
             merge(df, wrong_type, left_on="a", right_on="a")
 
-    def test_join_on_pass_vector(self):
-        expected = self.target.join(self.source, on="C")
-        del expected["C"]
+    def test_join_on_pass_vector(self, target_source):
+        target, source = target_source
+        expected = target.join(source, on="C")
+        expected = expected.rename(columns={"C": "key_0"})
+        expected = expected[["key_0", "A", "B", "D", "MergedA", "MergedD"]]
 
-        join_col = self.target.pop("C")
-        result = self.target.join(self.source, on=join_col)
+        join_col = target.pop("C")
+        result = target.join(source, on=join_col)
         tm.assert_frame_equal(result, expected)
 
-    def test_join_with_len0(self):
+    def test_join_with_len0(self, target_source):
         # nothing to merge
-        merged = self.target.join(self.source.reindex([]), on="C")
-        for col in self.source:
+        target, source = target_source
+        merged = target.join(source.reindex([]), on="C")
+        for col in source:
             assert col in merged
             assert merged[col].isna().all()
 
-        merged2 = self.target.join(self.source.reindex([]), on="C", how="inner")
+        merged2 = target.join(source.reindex([]), on="C", how="inner")
         tm.assert_index_equal(merged2.columns, merged.columns)
         assert len(merged2) == 0
 
@@ -297,7 +263,7 @@ class TestJoin:
 
         expected = df.join(df2, on="key")
         expected = expected[expected["value"].notna()]
-        tm.assert_series_equal(joined["key"], expected["key"], check_dtype=False)
+        tm.assert_series_equal(joined["key"], expected["key"])
         tm.assert_series_equal(joined["value"], expected["value"], check_dtype=False)
         tm.assert_index_equal(joined.index, expected.index)
 
@@ -311,9 +277,10 @@ class TestJoin:
 
         tm.assert_frame_equal(joined, expected)
 
-    def test_join_on_series(self):
-        result = self.target.join(self.source["MergedA"], on="C")
-        expected = self.target.join(self.source[["MergedA"]], on="C")
+    def test_join_on_series(self, target_source):
+        target, source = target_source
+        result = target.join(source["MergedA"], on="C")
+        expected = target.join(source[["MergedA"]], on="C")
         tm.assert_frame_equal(result, expected)
 
     def test_join_on_series_buglet(self):
@@ -381,10 +348,12 @@ class TestJoin:
 
     def test_join_unconsolidated(self):
         # GH #331
-        a = DataFrame(randn(30, 2), columns=["a", "b"])
-        c = Series(randn(30))
+        a = DataFrame(
+            np.random.default_rng(2).standard_normal((30, 2)), columns=["a", "b"]
+        )
+        c = Series(np.random.default_rng(2).standard_normal(30))
         a["c"] = c
-        d = DataFrame(randn(30, 1), columns=["q"])
+        d = DataFrame(np.random.default_rng(2).standard_normal((30, 1)), columns=["q"])
 
         # it works!
         a.join(d)
@@ -401,8 +370,16 @@ class TestJoin:
             names=["first", "second"],
         )
 
-        df1 = DataFrame(data=np.random.randn(6), index=index1, columns=["var X"])
-        df2 = DataFrame(data=np.random.randn(6), index=index2, columns=["var Y"])
+        df1 = DataFrame(
+            data=np.random.default_rng(2).standard_normal(6),
+            index=index1,
+            columns=["var X"],
+        )
+        df2 = DataFrame(
+            data=np.random.default_rng(2).standard_normal(6),
+            index=index2,
+            columns=["var Y"],
+        )
 
         df1 = df1.sort_index(level=0)
         df2 = df2.sort_index(level=0)
@@ -425,7 +402,7 @@ class TestJoin:
         tm.assert_frame_equal(joined, expected)
         assert joined.index.names == index1.names
 
-    def test_join_inner_multiindex(self):
+    def test_join_inner_multiindex(self, lexsorted_two_level_string_multiindex):
         key1 = ["bar", "bar", "bar", "foo", "foo", "baz", "baz", "qux", "qux", "snap"]
         key2 = [
             "two",
@@ -440,16 +417,14 @@ class TestJoin:
             "one",
         ]
 
-        data = np.random.randn(len(key1))
+        data = np.random.default_rng(2).standard_normal(len(key1))
         data = DataFrame({"key1": key1, "key2": key2, "data": data})
 
-        index = MultiIndex(
-            levels=[["foo", "bar", "baz", "qux"], ["one", "two", "three"]],
-            codes=[[0, 0, 0, 1, 1, 2, 2, 3, 3, 3], [0, 1, 2, 0, 1, 1, 2, 0, 1, 2]],
-            names=["first", "second"],
-        )
+        index = lexsorted_two_level_string_multiindex
         to_join = DataFrame(
-            np.random.randn(10, 3), index=index, columns=["j_one", "j_two", "j_three"]
+            np.random.default_rng(2).standard_normal((10, 3)),
+            index=index,
+            columns=["j_one", "j_two", "j_three"],
         )
 
         joined = data.join(to_join, on=["key1", "key2"], how="inner")
@@ -484,38 +459,48 @@ class TestJoin:
         expected = expected.drop(["first", "second"], axis=1)
         expected.index = joined.index
 
-        assert joined.index.is_monotonic
+        assert joined.index.is_monotonic_increasing
         tm.assert_frame_equal(joined, expected)
 
         # _assert_same_contents(expected, expected2.loc[:, expected.columns])
 
-    def test_join_hierarchical_mixed(self):
+    def test_join_hierarchical_mixed_raises(self):
         # GH 2024
+        # GH 40993: For raising, enforced in 2.0
         df = DataFrame([(1, 2, 3), (4, 5, 6)], columns=["a", "b", "c"])
-        new_df = df.groupby(["a"]).agg({"b": [np.mean, np.sum]})
+        new_df = df.groupby(["a"]).agg({"b": ["mean", "sum"]})
         other_df = DataFrame([(1, 2, 3), (7, 10, 6)], columns=["a", "b", "d"])
         other_df.set_index("a", inplace=True)
         # GH 9455, 12219
-        with tm.assert_produces_warning(UserWarning):
-            result = merge(new_df, other_df, left_index=True, right_index=True)
-        assert ("b", "mean") in result
-        assert "b" in result
+        with pytest.raises(
+            pd.errors.MergeError, match="Not allowed to merge between different levels"
+        ):
+            merge(new_df, other_df, left_index=True, right_index=True)
 
     def test_join_float64_float32(self):
-
-        a = DataFrame(randn(10, 2), columns=["a", "b"], dtype=np.float64)
-        b = DataFrame(randn(10, 1), columns=["c"], dtype=np.float32)
+        a = DataFrame(
+            np.random.default_rng(2).standard_normal((10, 2)),
+            columns=["a", "b"],
+            dtype=np.float64,
+        )
+        b = DataFrame(
+            np.random.default_rng(2).standard_normal((10, 1)),
+            columns=["c"],
+            dtype=np.float32,
+        )
         joined = a.join(b)
         assert joined.dtypes["a"] == "float64"
         assert joined.dtypes["b"] == "float64"
         assert joined.dtypes["c"] == "float32"
 
-        a = np.random.randint(0, 5, 100).astype("int64")
-        b = np.random.random(100).astype("float64")
-        c = np.random.random(100).astype("float32")
+        a = np.random.default_rng(2).integers(0, 5, 100).astype("int64")
+        b = np.random.default_rng(2).random(100).astype("float64")
+        c = np.random.default_rng(2).random(100).astype("float32")
         df = DataFrame({"a": a, "b": b, "c": c})
         xpdf = DataFrame({"a": a, "b": b, "c": c})
-        s = DataFrame(np.random.random(5).astype("float32"), columns=["md"])
+        s = DataFrame(
+            np.random.default_rng(2).random(5).astype("float32"), columns=["md"]
+        )
         rs = df.merge(s, left_on="a", right_index=True)
         assert rs.dtypes["a"] == "int64"
         assert rs.dtypes["b"] == "float64"
@@ -564,8 +549,8 @@ class TestJoin:
             {
                 "A": ["foo", "bar", "foo", "bar", "foo", "bar", "foo", "foo"],
                 "B": ["one", "one", "two", "three", "two", "two", "one", "three"],
-                "C": np.random.randn(8),
-                "D": np.random.randn(8),
+                "C": np.random.default_rng(2).standard_normal(8),
+                "D": np.random.default_rng(2).standard_normal(8),
             }
         )
         s = Series(
@@ -579,24 +564,30 @@ class TestJoin:
         tm.assert_frame_equal(inner, left)
         tm.assert_frame_equal(inner, right)
 
-    def test_join_sort(self):
-        left = DataFrame({"key": ["foo", "bar", "baz", "foo"], "value": [1, 2, 3, 4]})
-        right = DataFrame({"value2": ["a", "b", "c"]}, index=["bar", "baz", "foo"])
+    @pytest.mark.parametrize(
+        "infer_string", [False, pytest.param(True, marks=td.skip_if_no("pyarrow"))]
+    )
+    def test_join_sort(self, infer_string):
+        with option_context("future.infer_string", infer_string):
+            left = DataFrame(
+                {"key": ["foo", "bar", "baz", "foo"], "value": [1, 2, 3, 4]}
+            )
+            right = DataFrame({"value2": ["a", "b", "c"]}, index=["bar", "baz", "foo"])
 
-        joined = left.join(right, on="key", sort=True)
-        expected = DataFrame(
-            {
-                "key": ["bar", "baz", "foo", "foo"],
-                "value": [2, 3, 1, 4],
-                "value2": ["a", "b", "c", "c"],
-            },
-            index=[1, 2, 0, 3],
-        )
-        tm.assert_frame_equal(joined, expected)
+            joined = left.join(right, on="key", sort=True)
+            expected = DataFrame(
+                {
+                    "key": ["bar", "baz", "foo", "foo"],
+                    "value": [2, 3, 1, 4],
+                    "value2": ["a", "b", "c", "c"],
+                },
+                index=[1, 2, 0, 3],
+            )
+            tm.assert_frame_equal(joined, expected)
 
-        # smoke test
-        joined = left.join(right, on="key", sort=False)
-        tm.assert_index_equal(joined.index, pd.Index(list(range(4))))
+            # smoke test
+            joined = left.join(right, on="key", sort=False)
+            tm.assert_index_equal(joined.index, Index(range(4)), exact=True)
 
     def test_join_mixed_non_unique_index(self):
         # GH 12814, unorderable types in py3 with a non-unique index
@@ -632,19 +623,27 @@ class TestJoin:
 
     def test_mixed_type_join_with_suffix(self):
         # GH #916
-        df = DataFrame(np.random.randn(20, 6), columns=["a", "b", "c", "d", "e", "f"])
+        df = DataFrame(
+            np.random.default_rng(2).standard_normal((20, 6)),
+            columns=["a", "b", "c", "d", "e", "f"],
+        )
         df.insert(0, "id", 0)
         df.insert(5, "dt", "foo")
 
         grouped = df.groupby("id")
-        mn = grouped.mean()
+        msg = re.escape("agg function failed [how->mean,dtype->")
+        with pytest.raises(TypeError, match=msg):
+            grouped.mean()
+        mn = grouped.mean(numeric_only=True)
         cn = grouped.count()
 
         # it works!
         mn.join(cn, rsuffix="_right")
 
     def test_join_many(self):
-        df = DataFrame(np.random.randn(10, 6), columns=list("abcdef"))
+        df = DataFrame(
+            np.random.default_rng(2).standard_normal((10, 6)), columns=list("abcdef")
+        )
         df_list = [df[["a", "b"]], df[["c", "d"]], df[["e", "f"]]]
 
         joined = df_list[0].join(df_list[1:])
@@ -672,7 +671,10 @@ class TestJoin:
             df_list[0].join(df_list[1:], on="a")
 
     def test_join_many_mixed(self):
-        df = DataFrame(np.random.randn(8, 4), columns=["A", "B", "C", "D"])
+        df = DataFrame(
+            np.random.default_rng(2).standard_normal((8, 4)),
+            columns=["A", "B", "C", "D"],
+        )
         df["key"] = ["foo", "bar"] * 4
         df1 = df.loc[:, ["A", "B"]]
         df2 = df.loc[:, ["C", "D"]]
@@ -682,13 +684,16 @@ class TestJoin:
         tm.assert_frame_equal(result, df)
 
     def test_join_dups(self):
-
         # joining dups
         df = concat(
             [
-                DataFrame(np.random.randn(10, 4), columns=["A", "A", "B", "B"]),
                 DataFrame(
-                    np.random.randint(0, 10, size=20).reshape(10, 2), columns=["A", "C"]
+                    np.random.default_rng(2).standard_normal((10, 4)),
+                    columns=["A", "A", "B", "B"],
+                ),
+                DataFrame(
+                    np.random.default_rng(2).integers(0, 10, size=20).reshape(10, 2),
+                    columns=["A", "C"],
                 ),
             ],
             axis=1,
@@ -700,18 +705,28 @@ class TestJoin:
         tm.assert_frame_equal(result, expected)
 
         # GH 4975, invalid join on dups
-        w = DataFrame(np.random.randn(4, 2), columns=["x", "y"])
-        x = DataFrame(np.random.randn(4, 2), columns=["x", "y"])
-        y = DataFrame(np.random.randn(4, 2), columns=["x", "y"])
-        z = DataFrame(np.random.randn(4, 2), columns=["x", "y"])
+        w = DataFrame(
+            np.random.default_rng(2).standard_normal((4, 2)), columns=["x", "y"]
+        )
+        x = DataFrame(
+            np.random.default_rng(2).standard_normal((4, 2)), columns=["x", "y"]
+        )
+        y = DataFrame(
+            np.random.default_rng(2).standard_normal((4, 2)), columns=["x", "y"]
+        )
+        z = DataFrame(
+            np.random.default_rng(2).standard_normal((4, 2)), columns=["x", "y"]
+        )
 
         dta = x.merge(y, left_index=True, right_index=True).merge(
             z, left_index=True, right_index=True, how="outer"
         )
-        dta = dta.merge(w, left_index=True, right_index=True)
-        expected = concat([x, y, z, w], axis=1)
-        expected.columns = ["x_x", "y_x", "x_y", "y_y", "x_x", "y_x", "x_y", "y_y"]
-        tm.assert_frame_equal(dta, expected)
+        # GH 40991: As of 2.0 causes duplicate columns
+        with pytest.raises(
+            pd.errors.MergeError,
+            match="Passing 'suffixes' which cause duplicate columns",
+        ):
+            dta.merge(w, left_index=True, right_index=True)
 
     def test_join_multi_to_multi(self, join_type):
         # GH 20475
@@ -742,7 +757,7 @@ class TestJoin:
 
     def test_join_on_tz_aware_datetimeindex(self):
         # GH 23931, 26335
-        df1 = pd.DataFrame(
+        df1 = DataFrame(
             {
                 "date": pd.date_range(
                     start="2018-01-01", periods=5, tz="America/Chicago"
@@ -751,7 +766,7 @@ class TestJoin:
             }
         )
 
-        df2 = pd.DataFrame(
+        df2 = DataFrame(
             {
                 "date": pd.date_range(
                     start="2018-01-03", periods=5, tz="America/Chicago"
@@ -761,7 +776,7 @@ class TestJoin:
         )
         result = df1.join(df2.set_index("date"), on="date")
         expected = df1.copy()
-        expected["vals_2"] = pd.Series([np.nan] * 2 + list("tuv"), dtype=object)
+        expected["vals_2"] = Series([np.nan] * 2 + list("tuv"))
         tm.assert_frame_equal(result, expected)
 
     def test_join_datetime_string(self):
@@ -775,27 +790,42 @@ class TestJoin:
             ],
             columns=["x", "y", "a"],
         )
-        dfa["x"] = pd.to_datetime(dfa["x"])
+        dfa["x"] = pd.to_datetime(dfa["x"]).astype("M8[ns]")
         dfb = DataFrame(
             [["2012-08-02", "J", 1], ["2013-04-06", "L", 2]],
             columns=["x", "y", "z"],
             index=[2, 4],
         )
-        dfb["x"] = pd.to_datetime(dfb["x"])
+        dfb["x"] = pd.to_datetime(dfb["x"]).astype("M8[ns]")
         result = dfb.join(dfa.set_index(["x", "y"]), on=["x", "y"])
         expected = DataFrame(
             [
-                [pd.Timestamp("2012-08-02 00:00:00"), "J", 1, 15],
-                [pd.Timestamp("2013-04-06 00:00:00"), "L", 2, 20],
+                [Timestamp("2012-08-02 00:00:00"), "J", 1, 15],
+                [Timestamp("2013-04-06 00:00:00"), "L", 2, 20],
             ],
             index=[2, 4],
             columns=["x", "y", "z", "a"],
         )
+        expected["x"] = expected["x"].astype("M8[ns]")
+        tm.assert_frame_equal(result, expected)
+
+    def test_join_with_categorical_index(self):
+        # GH47812
+        ix = ["a", "b"]
+        id1 = pd.CategoricalIndex(ix, categories=ix)
+        id2 = pd.CategoricalIndex(reversed(ix), categories=reversed(ix))
+
+        df1 = DataFrame({"c1": ix}, index=id1)
+        df2 = DataFrame({"c2": reversed(ix)}, index=id2)
+        result = df1.join(df2)
+        expected = DataFrame(
+            {"c1": ["a", "b"], "c2": ["a", "b"]},
+            index=pd.CategoricalIndex(["a", "b"], categories=["a", "b"]),
+        )
         tm.assert_frame_equal(result, expected)
 
 
 def _check_join(left, right, result, join_col, how="left", lsuffix="_x", rsuffix="_y"):
-
     # some smoke tests
     for c in join_col:
         assert result[c].notna().all()
@@ -809,13 +839,11 @@ def _check_join(left, right, result, join_col, how="left", lsuffix="_x", rsuffix
 
         try:
             lgroup = left_grouped.get_group(group_key)
-        except KeyError:
+        except KeyError as err:
             if how in ("left", "inner"):
                 raise AssertionError(
-                    "key {group_key!s} should not have been in the join".format(
-                        group_key=group_key
-                    )
-                )
+                    f"key {group_key} should not have been in the join"
+                ) from err
 
             _assert_all_na(l_joined, left.columns, join_col)
         else:
@@ -823,13 +851,11 @@ def _check_join(left, right, result, join_col, how="left", lsuffix="_x", rsuffix
 
         try:
             rgroup = right_grouped.get_group(group_key)
-        except KeyError:
+        except KeyError as err:
             if how in ("right", "inner"):
                 raise AssertionError(
-                    "key {group_key!s} should not have been in the join".format(
-                        group_key=group_key
-                    )
-                )
+                    f"key {group_key} should not have been in the join"
+                ) from err
 
             _assert_all_na(r_joined, right.columns, join_col)
         else:
@@ -882,3 +908,194 @@ def _join_by_hand(a, b, how="left"):
     for col, s in b_re.items():
         a_re[col] = s
     return a_re.reindex(columns=result_columns)
+
+
+def test_join_inner_multiindex_deterministic_order():
+    # GH: 36910
+    left = DataFrame(
+        data={"e": 5},
+        index=MultiIndex.from_tuples([(1, 2, 4)], names=("a", "b", "d")),
+    )
+    right = DataFrame(
+        data={"f": 6}, index=MultiIndex.from_tuples([(2, 3)], names=("b", "c"))
+    )
+    result = left.join(right, how="inner")
+    expected = DataFrame(
+        {"e": [5], "f": [6]},
+        index=MultiIndex.from_tuples([(1, 2, 4, 3)], names=("a", "b", "d", "c")),
+    )
+    tm.assert_frame_equal(result, expected)
+
+
+@pytest.mark.parametrize(
+    ("input_col", "output_cols"), [("b", ["a", "b"]), ("a", ["a_x", "a_y"])]
+)
+def test_join_cross(input_col, output_cols):
+    # GH#5401
+    left = DataFrame({"a": [1, 3]})
+    right = DataFrame({input_col: [3, 4]})
+    result = left.join(right, how="cross", lsuffix="_x", rsuffix="_y")
+    expected = DataFrame({output_cols[0]: [1, 1, 3, 3], output_cols[1]: [3, 4, 3, 4]})
+    tm.assert_frame_equal(result, expected)
+
+
+def test_join_multiindex_one_level(join_type):
+    # GH#36909
+    left = DataFrame(
+        data={"c": 3}, index=MultiIndex.from_tuples([(1, 2)], names=("a", "b"))
+    )
+    right = DataFrame(data={"d": 4}, index=MultiIndex.from_tuples([(2,)], names=("b",)))
+    result = left.join(right, how=join_type)
+    if join_type == "right":
+        expected = DataFrame(
+            {"c": [3], "d": [4]},
+            index=MultiIndex.from_tuples([(2, 1)], names=["b", "a"]),
+        )
+    else:
+        expected = DataFrame(
+            {"c": [3], "d": [4]},
+            index=MultiIndex.from_tuples([(1, 2)], names=["a", "b"]),
+        )
+    tm.assert_frame_equal(result, expected)
+
+
+@pytest.mark.parametrize(
+    "categories, values",
+    [
+        (["Y", "X"], ["Y", "X", "X"]),
+        ([2, 1], [2, 1, 1]),
+        ([2.5, 1.5], [2.5, 1.5, 1.5]),
+        (
+            [Timestamp("2020-12-31"), Timestamp("2019-12-31")],
+            [Timestamp("2020-12-31"), Timestamp("2019-12-31"), Timestamp("2019-12-31")],
+        ),
+    ],
+)
+def test_join_multiindex_not_alphabetical_categorical(categories, values):
+    # GH#38502
+    left = DataFrame(
+        {
+            "first": ["A", "A"],
+            "second": Categorical(categories, categories=categories),
+            "value": [1, 2],
+        }
+    ).set_index(["first", "second"])
+    right = DataFrame(
+        {
+            "first": ["A", "A", "B"],
+            "second": Categorical(values, categories=categories),
+            "value": [3, 4, 5],
+        }
+    ).set_index(["first", "second"])
+    result = left.join(right, lsuffix="_left", rsuffix="_right")
+
+    expected = DataFrame(
+        {
+            "first": ["A", "A"],
+            "second": Categorical(categories, categories=categories),
+            "value_left": [1, 2],
+            "value_right": [3, 4],
+        }
+    ).set_index(["first", "second"])
+    tm.assert_frame_equal(result, expected)
+
+
+@pytest.mark.parametrize(
+    "left_empty, how, exp",
+    [
+        (False, "left", "left"),
+        (False, "right", "empty"),
+        (False, "inner", "empty"),
+        (False, "outer", "left"),
+        (False, "cross", "empty"),
+        (True, "left", "empty"),
+        (True, "right", "right"),
+        (True, "inner", "empty"),
+        (True, "outer", "right"),
+        (True, "cross", "empty"),
+    ],
+)
+def test_join_empty(left_empty, how, exp):
+    left = DataFrame({"A": [2, 1], "B": [3, 4]}, dtype="int64").set_index("A")
+    right = DataFrame({"A": [1], "C": [5]}, dtype="int64").set_index("A")
+
+    if left_empty:
+        left = left.head(0)
+    else:
+        right = right.head(0)
+
+    result = left.join(right, how=how)
+
+    if exp == "left":
+        expected = DataFrame({"A": [2, 1], "B": [3, 4], "C": [np.nan, np.nan]})
+        expected = expected.set_index("A")
+    elif exp == "right":
+        expected = DataFrame({"B": [np.nan], "A": [1], "C": [5]})
+        expected = expected.set_index("A")
+    elif exp == "empty":
+        expected = DataFrame(columns=["B", "C"], dtype="int64")
+        if how != "cross":
+            expected = expected.rename_axis("A")
+    if how == "outer":
+        expected = expected.sort_index()
+
+    tm.assert_frame_equal(result, expected)
+
+
+def test_join_empty_uncomparable_columns():
+    # GH 57048
+    df1 = DataFrame()
+    df2 = DataFrame(columns=["test"])
+    df3 = DataFrame(columns=["foo", ("bar", "baz")])
+
+    result = df1 + df2
+    expected = DataFrame(columns=["test"])
+    tm.assert_frame_equal(result, expected)
+
+    result = df2 + df3
+    expected = DataFrame(columns=[("bar", "baz"), "foo", "test"])
+    tm.assert_frame_equal(result, expected)
+
+    result = df1 + df3
+    expected = DataFrame(columns=[("bar", "baz"), "foo"])
+    tm.assert_frame_equal(result, expected)
+
+
+@pytest.mark.parametrize(
+    "how, values",
+    [
+        ("inner", [0, 1, 2]),
+        ("outer", [0, 1, 2]),
+        ("left", [0, 1, 2]),
+        ("right", [0, 2, 1]),
+    ],
+)
+def test_join_multiindex_categorical_output_index_dtype(how, values):
+    # GH#50906
+    df1 = DataFrame(
+        {
+            "a": Categorical([0, 1, 2]),
+            "b": Categorical([0, 1, 2]),
+            "c": [0, 1, 2],
+        }
+    ).set_index(["a", "b"])
+
+    df2 = DataFrame(
+        {
+            "a": Categorical([0, 2, 1]),
+            "b": Categorical([0, 2, 1]),
+            "d": [0, 2, 1],
+        }
+    ).set_index(["a", "b"])
+
+    expected = DataFrame(
+        {
+            "a": Categorical(values),
+            "b": Categorical(values),
+            "c": values,
+            "d": values,
+        }
+    ).set_index(["a", "b"])
+
+    result = df1.join(df2, how=how)
+    tm.assert_frame_equal(result, expected)
